#!/usr/bin/perl

# Created by ./mk_str_mod.pl on Sun Apr 26 10:03:52 PDT 2009

package Lingua::PT::Infinitives ;
use Exporter ;
@ISA = qw(Exporter);
@EXPORT = qw( $infinitives );
$infinitives = <<EOSTR
abaetar
abafar
abaganhar
abainhar
abaixar
abalançar
abalar
abalizar
abalofar
abalroar
abanar
abancar
abandalhar
abandar
abandonar
abarbar
abarbatar
abarcar
abarracar
abarrancar
abarrotar
abastar
abastardar
abastecer
abastonar
abatatar
abater
abatocar
abatumar
abaular
abaçanar
abdicar
abduzir
abeberar
abecar
abeirar
abeiçar
abelhar
abelhudar
abemolar
abençoar
aberrar
aberturar
abesoirar
abesourar
abespinhar
abetumar
abicar
abichornar
abiscatar
abiscoitar
abismar
abisonhar
abispar
abjudicar
abjurar
abjurgar
ablegar
abnegar
abobar
abocanhar
abocar
aboiar
abojar
aboletar
abolir
abominar
abonançar
abonar
abordar
aborrecer
abortar
abotecar
abotoar
abrancar
abrandar
abrandecer
abranger
abrasar
abrasileirar
abrasilianar
abraçar
abrejar
abrenunciar
abreviar
abrigar
abrilhantar
abrir
abrochar
abrogar
abrolhar
abroquelar
abrumar
abrutalhar
absceder
abscindir
absconder
absolver
absonar
absorver
abster
abstrair
abufelar
abular
abundar
aburguesar
abusar
acabar
acaboclar
acabrunhar
acachapar
acachoar
academizar
acadimar
acafajestar
acaipirar
acaiçarar
acalcanhar
acalcar
acalentar
acalmar
acalorar
acalçar
acamar
acamaradar
acampar
acanalhar
acanastrar
acanavear
acanhalar
acanhar
acanivetar
acanteirar
acantonar
acapachar
acapangar
acapelar
acapoeirar
acapuchar
acardumar
acarear
acariciar
acarinhar
acarneirar
acarrancar
acarretar
acartar
acasalar
acasernar
acastanhar
acastelar
acatar
acatitar
acatruzar
acaudilhar
acautelar
acavalar
acaçapar
accionar
accorrer
aceder
aceitar
acelerar
acenar
acender
acentuar
acepilhar
acerar
acerbar
acercar
acertar
acervar
acessar
acetinar
achacar
achanar
achaparrar
achar
achatar
achavascar
achegar
achicar
achincalhar
achinelar
achinesar
acicatar
acicular
acidar
acidentar
acidificar
acidular
acinzar
acinzentar
acioinar
acionar
acirrar
acitrinar
acizentar
aclamar
aclarar
aclimar
aclimatar
aclimatizar
acobardar
acobertar
acocar
acochar
acocorar
acogular
acoimar
acoitar
acolchetar
acolchoar
acolher
acolherar
acomadrar
acometer
acomodar
acompadrar
acompanhar
acompassar
acompridar
aconchegar
acondicionar
acondimentar
aconselhar
aconsoantar
acontecer
acoplar
acopular
acoquinar
acordar
acoronhar
acorrentar
acorrer
acossar
acostar
acostumar
acotovelar
acovardar
acovilhar
acravar
acreditar
acrescentar
acrescer
acriançar
acrisolar
acromatizar
activar
actualizar
actuar
acudir
acumular
acurar
acurralar
acurvar
acusar
acutangular
acutilar
adagiar
adamascar
adaptar
adegar
adejar
adelgaçar
adensar
adentar
adentrar
adequar
aderir
adernar
adestrar
adeusar
adiamantar
adiantar
adiar
adicionar
adietar
adir
aditar
adivinhar
adjectivar
adjetivar
adjudicar
adjurar
adjutorar
adjuvar
adminicular
administrar
admirar
admitir
admoestar
adocicar
adoecer
adoentar
adoestar
adoidar
adolescer
adomar
adonar
adonisar
adoptar
adorar
adormecer
adormentar
adornar
adotar
adoçar
adquirir
adscrever
adstringir
adubar
adular
adulterar
adumbrar
adunar
aduzir
adverbializar
adverbiar
adverbizar
adversar
advertir
advir
advogar
afadigar
afagar
afainar
afamar
afanar
afastar
afazer
afectar
afeiçoar
afeminar
aferir
aferrar
aferroar
aferrolhar
aferventar
afervorar
afetar
afiambrar
afiançar
afiar
afidalgar
afigurar
afilar
afilhar
afiliar
afinar
afincar
afirmar
afivelar
afixar
aflar
aflautar
afleumar
afligir
aflorar
afluir
afobar
afocinhar
afofar
afogar
afoguear
afoitar
afolar
afolhar
afolozar
aforar
aformosar
aformosear
aforquilhar
aforrar
afortalezar
afortunar
afracar
afrancesar
afranzinar
afrechar
afreguesar
afrentar
afretar
africanar
africanizar
afronhar
afrontar
afrouxar
afugentar
afumar
afundar
afunilar
agachar
agadanhar
agaitar
agarotar
agarrar
agarrochar
agasalhar
agastar
agenciar
agendar
agigantar
agiotar
agir
agitar
aglomerar
aglutinar
agoirar
agoniar
agonizar
agourar
agourentar
agraciar
agradar
agradecer
agrafar
agravar
agredir
agregar
agremiar
agricultar
agrilhoar
agrimensar
agrisalhar
agrupar
aguar
aguardar
aguarelar
aguentar
aguerrilhar
aguerrir
aguilhar
aguilhoar
aguisar
aguitarrar
agulhar
aguçar
agüentar
aiar
ajanotar
ajardinar
ajeitar
ajoelhar
ajornalar
ajoujar
ajudar
ajuizar
ajuntar
ajuramentar
ajustar
ajustiçar
alacaiar
alagar
alapar
alar
alaranjar
alardear
alargar
alarmar
alastrar
alavercar
albardar
albergar
albufeirar
albuminar
alcaiotar
alcalinizar
alcançar
alcatear
alcatifar
alcatroar
alcofar
alcoolificar
alcoolizar
alcovitar
alcunhar
aldrabar
alegar
alegorizar
alegrar
aleijar
aleitar
alentar
alentecer
alertar
alesmar
alestar
alevantar
alfabetar
alfabetizar
alfaiar
alfaiatar
alfandegar
alfarrobar
alfazemar
alfinetar
alforjar
alforrar
alforriar
algaliar
algazarrar
algebrizar
algemar
alguidar
alhanar
alhear
aliançar
aliar
alicerçar
aliciar
alienar
aligeirar
alijar
alimentar
alimpar
alindar
alinhar
alinhavar
alisar
alistar
aliviar
aljofrar
almejar
almiscarar
almocrevar
almofadar
almoçar
almíscar
alocar
alojar
alombar
alongar
aloucar
alourar
alousar
alpendrar
alquebrar
alqueirar
alquimiar
alrotar
alterar
altercar
alternar
aluar
alucinar
aludir
alugar
aluir
alumbrar
alumiar
alunar
aluviar
aluvionar
alvejar
alveolar
alvissarar
alvitrar
alvorar
alvoraçar
alvorecer
alvoroçar
alçar
amacacar
amachucar
amaciar
amadrinhar
amadurecer
amainar
amalandrar
amaldiçoar
amalgamar
amalucar
amamentar
amancebar
amandrinhar
amanhar
amanhecer
amansar
amar
amarar
amarelar
amarelecer
amarfanhar
amargar
amargurar
amaricar
amarotar
amarrar
amarrotar
amartelar
amarujar
amasiar
amassar
amatutar
amazelar
ambicionar
ambientar
amealhar
amear
ameaçar
amedalhar
amedrontar
ameigar
ameijoar
ameninar
amenizar
americanizar
amesquinhar
amestrar
amezinhar
amigar
amigdalar
amimar
aminar
amiudar
amnistiar
amocambar
amodorrar
amoedar
amofinar
amoirar
amoitar
amojar
amolar
amoldar
amolecar
amolecer
amolengar
amolentar
amolgar
amontanhar
amontar
amontoar
amoralizar
amordaçar
amorenar
amoriscar
amornar
amorrinhar
amortalhar
amortecer
amortizar
amortiçar
amossar
amostrar
amotinar
amoucar
amourar
amouriscar
amouxar
amover
amparar
ampliar
amplificar
amputar
amuar
amulatar
amulherar
amulherengar
amumiar
amunhecar
amuralhar
amurar
anacronizar
anafar
analisar
ananicar
anarquizar
anatar
anatematizar
anatomizar
anavalhar
ancinhar
ancorar
andaimar
andar
andejar
anedotizar
anegrar
anelar
anemiar
anemizar
anestesiar
anexar
angariar
angelizar
anglicizar
angular
angustiar
anichar
aniilar
anilar
anilhar
anilinar
animalizar
animar
aninhar
aniquilar
anisar
anistiar
aniversariar
anoitecer
anojar
anonadar
anonimar
anortear
anotar
anovelar
ansiar
antagonizar
anteceder
antecipar
antedatar
anteder
antedizer
antegozar
antemostrar
antemover
antemurar
anteocular
anteocupar
antepagar
anteparar
antepassar
antepor
anteriorizar
antever
antevir
antipatizar
antiquar
antropomorfizar
anuir
anular
anunciar
anuviar
apachorrar
apadrinhar
apadroar
apagar
apaixonar
apalacianar
apaladar
apalancar
apalavrar
apalaçar
apalermar
apalhaçar
apalmar
apalpar
apancar
apanhar
apanicar
apaniguar
apantufar
apaparicar
aparafusar
aparar
aparceirar
aparcelar
aparecer
aparelhar
aparentar
apartar
aparvalhar
aparvoar
apassivar
apatifar
apatrulhar
apavonar
apavorar
apaziguar
apear
apedrar
apedrejar
apeganhar
apegar
apejar
apelar
apelidar
apelintrar
apensar
apequenar
aperaltar
aperceber
aperfeiçoar
aperfilhar
apertar
aperuar
apetecer
apetitar
apetrechar
apeçonhar
apeçonhentar
apiançar
apiedar
apilhar
apimentar
apimpolhar
apincelar
apingentar
apinhar
apinhoar
apintalhar
apipar
apisoar
apitar
aplacar
aplainar
aplanar
aplaudir
aplicar
apoderar
apodrecer
apodrentar
apodrir
apoiar
apologizar
apoltronar
apolvilhar
apontar
apoquentar
apor
aportar
aportuguesar
aposentar
apossar
apostar
apostolar
apostolizar
apostrofar
apotentar
apoteosar
apoucar
aprazar
aprazer
apreciar
apreender
aprefixar
apregoar
aprender
apresar
apresentar
apressar
apressurar
aprestamar
aprestar
apreçar
aprimorar
aprincesar
aprisionar
aproar
aprochegar
aprofundar
aprontar
apropinquar
apropositar
apropriar
aprosar
aprouver
aprovar
aproveitar
aprovisionar
aproximar
aprumar
aptar
apunhalar
apupar
apurar
aquadrelar
aquadrilhar
aquarelar
aquartelar
aquartilhar
aquecer
aquentar
aquiescer
aquietar
aquilatar
aquinhoar
arabizar
aradar
aramar
aranhar
arapuar
arar
arbitrar
arborescer
arborizar
arcabouçar
arcabuzar
arcar
arder
arejar
arengar
areolar
arfar
argamassar
argolar
arguciar
arguir
argumentar
argüir
arianizar
ariscar
aristocratizar
armar
armazenar
armilar
aromar
aromatizar
arpar
arpear
arpoar
arquear
arquejar
arquitectar
arquitetar
arquivar
arrabujar
arraigar
arrancar
arranchar
arrancorar
arranhar
arranjar
arrapazar
arrasar
arrastar
arraçar
arrear
arrebanhar
arrebatar
arrebentar
arrebitar
arrebolar
arrecadar
arrecuar
arredar
arredondar
arrefecer
arrefentar
arrefeçar
arregalar
arreganhar
arregaçar
arregimentar
arreglar
arregrar
arreigar
arrelampar
arreliar
arrelvar
arrematar
arremedar
arremessar
arremeter
arrendar
arrenegar
arrepanhar
arrepelar
arrepender
arrepiar
arrestar
arretar
arrevesar
arrevessar
arriar
arribar
arrimar
arriscar
arrobar
arrochar
arrodelar
arrogar
arroiar
arrojar
arrolar
arrolhar
arromançar
arrombar
arrostar
arrotar
arrotear
arroxar
arroxear
arruar
arruaçar
arrufar
arrugar
arruinar
arrulhar
arrumar
arruçar
arterializar
articular
artificiar
artilhar
artolar
arvoar
arvorar
asar
ascender
asfaltar
asfixiar
asilar
asnear
aspirar
assaborar
assalariar
assaltar
assanhar
assapatar
assar
assarapantar
assassinar
assear
assedar
assediar
assegurar
assemelhar
assenhorar
assenhorear
assentar
assentir
asserenar
asserir
assertar
assessorar
assetar
asseverar
assidrar
assimilar
assinalar
assinar
assingelar
assistir
assoalhar
assoar
assobarcar
assoberbar
assobiar
assocializar
associar
assolapar
assolar
assoldadar
assoleimar
assomar
assombrar
assombrear
assoprar
assorear
assossegar
assotar
assovelar
assovinar
assuar
assumir
assuntar
assustar
astralizar
astuciar
atabafar
atabalhoar
atabernar
atacanhar
atacar
atafulhar
atalaiar
atalhar
atamancar
atapetar
atar
atarantar
atardar
atarefar
atarracar
atarraxar
atassalhar
ataviar
atazanar
atear
atediar
atelier
atemorizar
atempar
atenazar
atendar
atender
atentar
atenuar
aterraplanar
aterrar
aterrissar
aterrizar
aterroar
aterrorar
aterrorizar
atestar
atijolar
atinar
atingir
atintar
atirar
ativar
atiçar
atiçoar
atoalhar
atolambar
atolar
atoleimar
atomatar
atombar
atomizar
atonar
atontar
atontear
atopetar
atordoar
atormentar
atoucinhar
atoxicar
atracar
atrafegar
atrair
atraiçoar
atrancar
atrapalhar
atrasar
atravacar
atravancar
atravessar
atrelar
atrepar
atrever
atribuir
atribular
atrincheirar
atroar
atrofiar
atropar
atropelar
atroçoar
atualizar
atuar
atufar
atulhar
atumultuar
aturar
aturdir
auferir
augir
augurar
aumentar
aureolar
auricular
aurificar
aurorar
aurorescer
auscultar
ausentar
auspiciar
austerizar
autenticar
autentificar
autocopiar
autografar
automatizar
automobilizar
autonomizar
autopsiar
autorebobinar
autorepetir
autoresumir
autorizar
auxiliar
avacalhar
avaladar
avaliar
avalizar
avaloar
avaluar
avantajar
avançar
avariar
avassalar
avelhacar
avelhar
avelhentar
aveludar
aventar
aventurar
avençar
averbar
averiguar
avermelhar
averrugar
averter
avessar
avezar
aviar
avicular
avigorar
avilanar
aviltar
avinagrar
avincar
avinhar
avioletar
avir
avisar
avistar
avivar
aviventar
avizinhar
avocar
avolumar
avultar
axilar
axiomatizar
azafamar
azagaiar
azar
azarar
azebrar
azedar
azeitar
azeitonar
azoinar
azotar
azular
azulejar
açacalar
açaimar
açambarcar
açancalar
açodar
açoitar
açorar
açucar
açucarar
açudar
açular
açúcar
babar
babujar
bacanalizar
bacelar
bacharelar
bachicar
bacilar
bacilizar
bacorejar
badalar
badalejar
badanar
badelhar
badernar
bafar
bafejar
baforar
bagar
bagunçar
bailar
bainhar
baixar
bajular
balancear
balançar
balbuciar
balburdiar
baldar
baldear
baldrocar
balear
balizar
balnear
baloiçar
balouçar
balsamar
balsamizar
bambalear
bambear
bambolear
banalisar
banalizar
bandarilhar
bandear
bandeirar
bandolear
banhar
banir
banquetear
banzar
baptizar
baquear
bar
barafustar
baralhar
baratear
baratinar
barbar
barbarizar
barbear
barganhar
barlaventear
barlaventejar
baronizar
barrar
barreirar
barricar
barulhar
basear
basificar
basilar
bastar
batalhar
bater
batizar
batotar
batotear
batucar
bazar
bazofiar
beatificar
beber
beberar
bebericar
beberricar
bedelhar
beijar
beijocar
beirar
beliscar
bemolar
bemolizar
bendizer
beneficiar
benfeitorizar
benzer
berrar
berregar
besoirar
besourar
bestar
bestializar
bestificar
besuntar
betonar
betumar
bexigar
biangular
bibliografar
bicapsular
bicar
bicelular
bichanar
bichar
bifar
bifurcar
bigamizar
biglandular
biglobular
bigodear
bilhar
bilhardar
biliar
bilocular
bilontrar
binocular
binoculizar
binuclear
biografar
bipartir
bipolar
birrar
bisar
bisbilhotar
biscar
biscatear
biscoitar
biscoutar
biselar
bisnagar
bispar
bissectar
bissecular
bitolar
bivacar
blasfemar
blasonar
blefar
blindar
bloquear
boatar
bobear
bobinar
bocejar
bochechar
bodejar
bofar
bofetear
boiar
boicotar
boicotear
bojar
bolar
bolchevizar
bolear
bolhar
bolinar
bolorecer
bolsar
bombardear
bombear
bonificar
boquejar
borboletear
borborejar
borbotar
borbulhar
bordar
bordejar
borrar
borratar
borregar
borrifar
bostar
botar
bouçar
boçalizar
bracear
bracejar
bradar
bradejar
bramar
bramir
brandir
branquear
branquejar
brasar
brasonar
bravatear
brear
brecar
brejeirar
brevetar
brigar
brilhar
brincar
brindar
briquitar
britar
brocar
brochar
bromar
bronquear
bronzear
brotar
brunir
brutalizar
bruxar
bucelar
bufar
bufonear
bugiar
bular
bulhar
bulir
buquinar
buracar
burburinhar
burilar
burlar
burocratizar
burrificar
buscar
buzinar
cabalar
cabecear
caber
cabriolar
cabritar
cabular
cacarejar
cacetear
cachear
cachimbar
cachinar
cachoeirar
cachuchar
cacicar
cadastrar
cadenciar
caducar
cafifar
cagar
caiar
cair
calafetar
calar
calcanhar
calcar
calcetar
calcificar
calcinar
calcografar
calcorrear
calcular
caldar
caldear
caldeirar
calejar
calhar
calhoar
calibrar
caliginar
caligrafar
calmar
calorificar
calotear
caluniar
calvar
calçar
cambalear
cambalhotar
cambiar
caminhar
campear
camuflar
camurçar
canalizar
cancelar
cancerar
cancerizar
candidatar
candongar
canelar
canforar
cangar
canhonar
canhonear
canibalizar
canonizar
cansar
cantar
cantarar
cantarejar
cantarolar
caotizar
capacitar
capar
capear
capengar
capenguear
capiangar
capilar
capinar
capiscar
capitalizar
capitanear
capitular
capoeirar
capotar
capotear
caprichar
capsular
captar
capturar
capuchar
caracolar
caracter
caracterizar
carambolar
caramelizar
carbonizar
carburar
cardar
carecer
cariar
caricaturar
cariciar
carimbar
carnalizar
carnifazer
carnificar
carpinteirar
carpir
carranquear
carrear
carregar
carretear
carrilar
carrilhonar
carroçar
cartografar
cartonar
carujar
carunchar
carvoejar
casalar
casamentar
casar
cascalhar
cascar
cascatear
casquilhar
cassar
castanholar
castelhanizar
castificar
castigar
castiçar
castrar
catadupejar
catalisar
catalogar
catapultar
catar
catarrear
catedratizar
categorizar
catequizar
catingar
catitar
cativar
catolicizar
catolizar
catrafilar
caucionar
caulificar
caulinar
causalizar
causar
causticar
cautelar
cauterizar
cavacar
cavalar
cavaleirar
cavalgar
cavaquear
cavar
cavernar
caviar
cavilhar
cavoucar
caçar
caçoar
cear
cecear
ceder
cedilhar
cegar
ceifar
celebrar
celebrizar
celeumar
celular
censurar
centelhar
centenar
centralizar
centrar
centrifugar
centuplicar
cercar
cercear
cerebralizar
cerimoniar
cernir
cerrar
certar
certificar
cerzir
cessar
cevar
chacinar
chacoalhar
chacolhar
chacotear
chafurdar
chagar
chalacear
chalaçar
chalrar
chalrear
chamar
chamejar
champanhizar
chamuscar
chancelar
chanfrar
chantajar
chapar
chapear
chapinar
chapinhar
chapiscar
charlatanear
charruar
chatear
chatinar
checar
chefiar
chegar
cheirar
chiar
chibatar
chicotear
chifrar
chilrar
chilrear
chimpar
chincalhar
chincar
chinfrinar
chirriar
chispar
chocalhar
chocar
chochar
chofrar
choramingar
chorar
chorriscar
chover
chuchar
chulear
chumaçar
chumbar
chumbear
chupar
churrasquear
chutar
chuvinhar
chuviscar
cicatrizar
cientificar
cifrar
ciganar
ciganear
cigarrar
ciliar
cilindrar
cimentar
cindir
cinematografar
cingir
cintar
cintilar
cinturar
cinzar
cinzelar
cirandar
circuitar
circular
circuncidar
circundar
circungirar
circunscrever
circunstanciar
circuntornar
circunvagar
circunvalar
circunvolver
cisar
ciscar
cismar
citar
ciumar
civilizar
clamar
clarear
clarejar
clarificar
clarimostrar
classificar
claudicar
claustrar
clausular
clausurar
clavicular
clemenciar
clericalizar
clicar
climatizar
clisterizar
clivar
cloroformizar
coabitar
coadaptar
coadjuvar
coadquirir
coadunar
coagir
coagitar
coagular
coalhar
coar
coaxar
cobaltizar
cobiçar
cobrar
cobrir
cocar
cocegar
cochar
cochichar
cochilar
codificar
coeducar
coerir
coexistir
cofiar
cogitar
cognominar
coibir
coicear
coincidir
coindicar
coisificar
coitar
colaborar
colar
colchetear
colchoar
coleccionar
colecionar
colectar
coletar
colher
colidir
coligar
coligir
colimar
colinear
colmar
colmatar
colmaçar
colocar
colonizar
colorar
colorear
colorir
colunar
comandar
combalir
combater
combinar
comedir
comemorar
comensurar
comentar
comer
comercializar
comerciar
cometar
cometer
começar
comichar
cominar
comiserar
comissionar
comocionar
comover
compactar
compactuar
compadecer
compadrar
compaginar
comparar
comparecer
comparticipar
compartilhar
compartir
compassar
compatibilizar
compelir
compendiar
compenetrar
compensar
competir
compilar
complanar
complementar
completar
complicar
compor
comportar
comprar
comprazer
compreender
comprimir
comprometer
comprouver
comprovar
compulsar
compungir
computar
comungar
comunicar
comutar
concatenar
conceber
conceder
conceituar
concelebrar
concentrar
conceptualizar
concernir
concertar
concessionar
conchavar
conchegar
conciliar
concitar
conclamar
concluir
concordar
concorrer
concretizar
concriar
concubinar
conculcar
concutir
condecorar
condenar
condensar
condescender
condicionar
condimentar
condizer
condoer
condutar
conduzir
conectar
confabular
confeccionar
confederar
conferenciar
conferir
confessar
confiar
confidenciar
configurar
confinar
confirmar
confiscar
conflagrar
conflitar
confluir
conformar
confortar
confranger
confraternar
confraternizar
confrontar
confundir
confutar
congelar
congeminar
congestionar
conglobar
conglomerar
conglutinar
congratular
congraçar
congregar
conhecer
conjecturar
conjeturar
conjugar
conjuntar
conjurar
conotar
conquistar
consagrar
consciencializar
conscientizar
conseguir
consentir
consertar
conservar
considerar
consignar
consistir
consoar
consociar
consolar
consolidar
consonantizar
consonar
consorciar
conspirar
conspurcar
constar
constatar
constelar
consternar
constipar
constitucionalizar
constituir
constranger
constringir
construir
consubstanciar
consular
consultar
consumar
consumir
contabilizar
contactar
contagiar
contaminar
contar
contatar
contemplar
contemporizar
contender
contentar
conter
contestar
contextuar
contiguar
continuar
contiver
contorcer
contorcionar
contornar
contornear
contrabalançar
contrabandear
contrabater
contracenar
contracunhar
contradeclarar
contraditar
contradizer
contrafazer
contrafortar
contrair
contramandar
contramanobrar
contramarcar
contramarchar
contramurar
contrapesar
contraplacar
contrapontear
contrapor
contraproduzir
contrapropor
contraprovar
contrariar
contrastar
contrastear
contratar
contratestemunhar
contraverter
contravir
contribuir
contristar
controlar
controverter
contundir
conturbar
convalescer
convalidar
convencer
convencionar
conventicular
convergir
conversar
converter
convidar
convir
conviver
convocar
convolver
convulsar
convulsionar
coobrigar
cooperar
cooptar
coordenar
copiar
copular
corar
corcovar
corcovear
cordear
cordoar
cornear
cornetear
cornificar
coroar
corporalizar
corporificar
corporizar
corpuscular
correger
correlacionar
correlatar
correr
corresponder
corretar
corricar
corrigir
corroborar
corroer
corromper
corrupiar
cortar
cortejar
cortinar
corujar
coscuvilhar
coser
cosmopolizar
costear
costumar
costurar
cotar
cotejar
cotizar
cotovelar
couber
couraçar
coutar
coxear
cozer
cozinhar
coçar
crapulear
cravar
cravejar
creditar
cremar
crepitar
crepuscular
crepusculizar
crer
crescer
crespar
crestar
cretinizar
criar
criminalizar
criptografar
crismar
crispar
cristalizar
cristianizar
criticar
crivar
cromar
cromatizar
cronicar
croniquizar
cronometrar
crucificar
cruzar
cubar
cucar
cucarachiar
cuidar
culminar
culpar
cultivar
cumpliciar
cumprimentar
cumprir
cumular
cunhar
curar
curricular
cursar
curtir
curvar
curvejar
cuspilhar
cuspir
custar
custear
custodiar
cutucar
dactilografar
danar
danificar
dançar
dançaricar
dar
dardejar
datar
datilografar
dealbar
deambular
debandar
debater
debelar
debicar
debilitar
debitar
debochar
debruçar
debulhar
debutar
debuxar
decair
decalcar
decampar
decangular
decantar
decapitar
deceinar
decepar
decepcionar
decidir
decifrar
decilitrar
declamar
declarar
declinar
declivar
decompor
decorar
decorrer
decotar
decrementar
decrepitar
decrescer
decretar
decriptar
dedetizar
dedicar
dedilhar
deduzir
defecar
defender
defensar
deferir
definhar
definir
deflagrar
deflectir
deflorar
defluir
deformar
defraudar
defrontar
defumar
degastar
degelar
degenerar
deglutir
degolar
degradar
degredar
degringolar
degustar
deificar
deitar
deixar
dejectar
delamber
delapidar
delatar
delegar
deleitar
deliberar
deliciar
delimitar
delinear
delinquir
delirar
delongar
demandar
demarcar
dementar
demitir
demitizar
democratizar
demografar
demolir
demonstrar
demorar
demover
denegar
denegrir
denigrir
denominar
denotar
dentar
denticular
denudar
denunciar
deparar
depauperar
depauperizar
depenar
depender
dependurar
depenicar
deperecer
depilar
deplorar
depor
deportar
depositar
depravar
deprecar
depreciar
depredar
depreender
deprimir
depurar
deputar
derivar
derramar
derrapar
derrear
derreter
derribar
derriçar
derrocar
derrogar
derrotar
derrubar
desabafar
desabalar
desabar
desabilitar
desabitar
desabonar
desabotoar
desabrigar
desabrochar
desabusar
desacatar
desacautelar
desacerelar
desacertar
desacomodar
desacompanhar
desaconchegar
desaconselhar
desacostumar
desacreditar
desadaptar
desafiar
desafinar
desafogar
desaforar
desafrontar
desagarrar
desagasalhar
desagradar
desagravar
desagregar
desaguar
desairar
desajeitar
desajustar
desalentar
desaliar
desalinhar
desalinhavar
desalistar
desalmar
desalojar
desalugar
desamarrar
desamassar
desambientar
desamontoar
desamparar
desancar
desandar
desanexar
desanimar
desaninhar
desanuviar
desaparafusar
desaparecer
desapartar
desapear
desapegar
desapertar
desapoderar
desapontar
desapossar
desapreciar
desapropriar
desaprovar
desaprumar
desarmar
desarmonizar
desarraigar
desarranchar
desarranjar
desarrochar
desarrolhar
desarrumar
desarticular
desarvorar
desassociar
desassombrar
desassossegar
desatar
desatarraxar
desatender
desatestar
desatinar
desativar
desatolar
desatracar
desatravacar
desatrelar
desatribuir
desatualizar
desaurir
desautorizar
desavisar
desbancar
desbandar
desbaratar
desbastar
desbordar
desboroar
desbotar
desbotoar
desbravar
descabelar
descalcificar
descalçar
descamar
descambar
descampar
descansar
descarar
descarnar
descaroçar
descarregar
descartar
descascar
descender
descentralizar
descer
descerrar
desclassificar
descloretar
descobrir
descoimar
descolar
descolorar
descolorir
descompactar
descompassar
descomprimir
desconcentrar
desconchavar
desconectar
desconfiar
descongelar
descongestionar
desconhecer
desconjuntar
desconjurar
desconsertar
desconsiderar
desconsolar
descontar
descontentar
descontrolar
desconversar
descortinar
descortiçar
descoser
descrever
descriminar
descuidar
desculpar
descurar
desdenhar
desdizer
desdobrar
desejar
desemaranhar
desembalar
desembaralhar
desembaraçar
desembarcar
desembargar
desembestar
desembirrar
desembocar
desembrulhar
desembuchar
desemburrar
desempacar
desemparelhar
desempatar
desempecer
desempecilhar
desempenar
desempenhar
desempilhar
desempregar
desencabeçar
desencachar
desencadear
desencaixar
desencalacrar
desencalhar
desencaminhar
desencantar
desencardir
desencarregar
desencarreirar
desencarrilar
desencarrilhar
desenconchar
desencontrar
desencorajar
desencostar
desencravar
desencrencar
desencrostar
desenfaixar
desenferrujar
desenfiar
desenfrear
desenfurnar
desengajar
desenganar
desengasgar
desengatar
desengatilhar
desengonçar
desengrainhar
desengrenar
desenguiçar
desenhar
desenlaçar
desenquadrar
desenredar
desenrolar
desenroscar
desenrugar
desentalar
desenteder
desenterrar
desentorpecer
desentortar
desentranhar
desentravar
desentulhar
desenvencilhar
desenvolver
desenxabir
desenxamear
desenxofrar
desequilibrar
deserdar
desertar
desesperançar
desesperar
desfalcar
desfalecer
desfasar
desfavorecer
desfazar
desfazer
desfaçar
desfear
desfeitear
desfibrar
desfigurar
desfilar
desfilhar
desflorar
desflorestar
desfolhar
desformatar
desforrar
desfragmentar
desfraldar
desfrutar
desgarrar
desgastar
desgostar
desgovernar
desgraçar
desgrenhar
desgrilhoar
desgrudar
desguedelhar
desidratar
designar
desiludir
desinchar
desinclinar
desincorporar
desincumbir
desindexar
desinfectar
desinfetar
desinibir
desintegrar
desinteressar
desintoxicar
desintrincar
desistir
deslanchar
deslaçar
desleixar
desligar
deslindar
deslisar
deslizar
deslocar
deslumbrar
desmaiar
desmamar
desmanchar
desmantelar
desmapear
desmarcar
desmascarar
desmembrar
desmentir
desmerecer
desmesurar
desmiolar
desmiudar
desmobilizar
desmontar
desmoralizar
desmoronar
desnatar
desnaturar
desnortear
desnudar
desobedecer
desobrigar
desobstruir
desocupar
desodorizar
desolar
desonrar
desopilar
desoprimir
desordenar
desorganizar
desorientar
desovar
despachar
despedaçar
despedir
despeitar
despeitorar
despejar
despelar
despencar
despender
despenhar
despentear
desperceber
desperdiçar
despersuadir
despertar
despetalar
despiedar
despiolhar
despir
despistar
despoetizar
despojar
despoletar
despongar
despontar
desposar
despotizar
desprender
despreocupar
desprestigiar
desprezar
desprimorar
despronunciar
despropositar
desproteger
desqualificar
desquitar
desraigar
desratizar
desregrar
desrespeitar
desresponsabilizar
dessangrar
destacar
destampar
destapar
desterrar
desterroar
destilar
destinar
destituir
destorcer
destrambelhar
destratar
destravar
destrichar
destrinçar
destronar
destroncar
destroçar
destruir
desumanizar
desumidificar
desunificar
desvairar
desvalorar
desvanecer
desvelar
desvencilhar
desvendar
desventrar
desventurar
desviar
desvincular
desvirginar
desvirtuar
detalhar
detectar
deter
deteriorar
determinar
detestar
detiver
detonar
detrair
deturpar
devagar
devanear
devassar
devastar
dever
devir
devolver
devorar
devotar
diagnosticar
diagramar
dialogar
dicionarizar
difamar
diferenciar
diferençar
diferir
dificultar
difractar
difundir
digerir
digitar
dignar
dignificar
digressionar
dilacerar
dilapidar
dilatar
diligenciar
diluir
diluviar
dimanar
dimensionar
diminuir
dinamitar
dinamizar
diplomar
direccionar
dirigir
dirimir
discar
discernir
disciplinar
discordar
discorrer
discrepar
discriminar
discursar
discurtir
discutir
disfarçar
disferir
disformar
disjuntar
disparar
disparatar
dispender
dispensar
dispersar
disponibilizar
dispor
disputar
dissecar
disseminar
dissertar
dissimilar
dissimular
dissipar
dissociar
dissolver
dissonar
dissuadir
distanciar
distar
distender
distinguir
distorcer
distrair
distratar
distribuir
disturbar
ditar
ditongar
divagar
divergir
diversificar
divertir
dividir
divinizar
divisar
divorciar
divulgar
dizer
dizimar
doar
dobar
dobrar
documentar
doer
doestar
dogmatizar
doidejar
doidivanar
doirar
domar
domesticar
domiciliar
dominar
dopar
dormir
dormitar
dosar
dosear
dotar
dourar
doutorar
doutrinar
dragar
dramatizar
drenar
driblar
dualizar
dublar
duelar
dulcificar
duplicar
durar
duvidar
díspar
ecicatar
eclipsar
eclodir
ecoar
economizar
edificar
editar
educar
efectivar
efectuar
efemerizar
efeminar
efeminizar
efervecer
efervescer
efetivar
efetuar
efluir
ejacular
ejectar
ejetar
elaborar
elastecer
electrificar
electrizar
electrocutar
electrolisar
eleger
elementar
eletrificar
eletrizar
eletrocutar
elevar
eliciar
elidir
eliminar
elixir
elogiar
elucidar
eludir
emaciar
emadeirar
emagrecer
emanar
emancipar
emaranhar
embaciar
embainhar
embalar
embalsamar
embalsar
embananar
embandeirar
embaralhar
embaratecer
embaraçar
embarcar
embargar
embarracar
embarrancar
embarrar
embarretar
embarricar
embasbacar
embater
embatocar
embaçar
embebecer
embebedar
embeber
embeiçar
embelecer
embelezar
embevecer
embicar
embirrar
emblemar
embocar
embodegar
embolar
embolorar
embolsar
emborcar
emborrachar
emborrar
emborrascar
emboscar
embotar
embraiar
embramar
embrandecer
embranquecer
embravecer
embrenhar
embriagar
embromar
embrulhar
embrumar
embruscar
embrutecer
embruxar
embuchar
emburguesar
emburrar
embustear
embutir
emendar
ementar
emergir
emigrar
eminenciar
emir
emitir
emocionar
emoldurar
empacar
empacotar
empalear
empalhar
empalheirar
empalidecer
empalmar
empanar
empancar
empantanar
empantufar
empanturrar
empapar
empapelar
emparceirar
emparcelar
emparedar
emparelhar
empastar
empastelar
empatar
empaçocar
empecer
empecilhar
empedernecer
empedernir
empedrar
empenar
empenhar
empenhorar
emperrar
empertigar
empestar
empetecar
empeçonhar
empilhar
empinar
empinocar
emplumar
empoar
empobrecer
empoeirar
empolar
empoleirar
empolgar
emporcalhar
emporcar
empossar
emprazar
empreender
empregar
empreitar
empresar
emprestar
emproar
emprumar
empunhar
empurrar
emudecer
emular
emulsionar
enaltecer
enamorar
encabelar
encabeçar
encabular
encadear
encadeirar
encadernar
encafuar
encaixar
encaixilhar
encaixotar
encalacrar
encalcar
encaldeirar
encalhar
encalçar
encamaçar
encaminhar
encamisar
encampar
encanar
encanastrar
encancerar
encandear
encandecer
encantar
encanteirar
encapar
encapelar
encapoeirar
encapotar
encaprichar
encapsular
encaracolar
encaramelar
encaramujar
encarangar
encarapinhar
encarapitar
encarapuçar
encarar
encarcerar
encardir
encarecer
encarnar
encarniçar
encarrapitar
encarregar
encarreirar
encarrilhar
encartar
encasacar
encascar
encasquetar
encastelar
encasular
encatrafiar
encavacar
encavaleirar
encavalgar
encavalitar
encavilhar
enceguecer
enceleirar
encenar
encerar
encerrar
encestar
encetar
encharcar
encher
enchoiriçar
enchumaçar
enchusmar
encilhar
encimar
enciumar
enclaustrar
enclausurar
enclavinhar
encobrir
encodear
encoleirar
encolerizar
encolher
encomendar
encompridar
encontrar
encorajar
encordoar
encornar
encoronhar
encorpar
encorrilhar
encortinar
encostar
encovar
encovilar
encravar
encrencar
encrespar
encrostar
encruar
encrudelecer
encruzilhar
encubar
encucar
encumear
encurralar
encurtar
encurvar
endemizar
endemoninhar
endereçar
endeusar
endiabrar
endinheirar
endireitar
endividar
endoidar
endoidecer
endossar
endoutrinar
endurecer
endurentar
enegrecer
energizar
enervar
enevoar
enfadar
enfaixar
enfarar
enfardar
enfarinhar
enfarpelar
enfarruscar
enfartar
enfastiar
enfatiotar
enfatizar
enfatuar
enfear
enfebrecer
enfeiar
enfeitar
enfeitiçar
enfeixar
enfermar
enferrujar
enfestar
enfeudar
enfezar
enfiar
enfileirar
enfivelar
enfocar
enfolar
enfolhar
enforcar
enformar
enfornar
enfortecer
enfraquecer
enfrascar
enfrentar
enfronhar
enfrouxecer
enfumaçar
enfunilar
enfurecer
enfurnar
engabelar
engaiolar
engajar
engalanar
engalfinhar
engalinhar
enganar
enganchar
engarrafar
engasgar
engastar
engatar
engatilhar
engatinhar
engavetar
engazopar
engelhar
engendrar
engenhar
engessar
englobar
engodar
engolfar
engolir
engomar
engordar
engordurar
engradar
engradear
engrandecer
engravidar
engraxar
engraçar
engrenar
engripar
engrossar
enguiçar
enigmar
enjambrar
enjaular
enjeitar
enjoar
enlambuzar
enlamear
enlanguescer
enlatar
enlaçar
enlevar
enliçar
enlouquecer
enlutar
enluvar
enobrecer
enojar
enovelar
enquadrar
enquistar
enrabar
enrabichar
enraivar
enraivecer
enraizar
enrascar
enredar
enregelar
enrijar
enrijecer
enriquecer
enriçar
enrobustecer
enrodilhar
enrolar
enrolhar
enroscar
enroupar
enrouquecer
enrubescer
enrudecer
enrugar
ensaboar
ensacar
ensaiar
ensandecer
ensanduichar
ensanguentar
ensangüentar
ensardinhar
ensebar
ensejar
ensinar
ensoalheirar
ensoberbecer
ensombrar
ensopar
ensurdecer
entabuar
entabular
entalar
entalhar
entanguecer
entaramelar
entardecer
entarraxar
entear
entediar
entelhar
entender
entenrecer
enternecer
enterrar
entesar
entesoirar
entesourar
entestar
enticar
entijolar
entimar
entisicar
entoar
entocar
entojar
entontar
entontecer
entornar
entorpecer
entortar
entranhar
entrançar
entrapar
entrar
entravar
entreabrir
entrecerrar
entrechocar
entrecortar
entregar
entrelaçar
entrelinhar
entremear
entremeter
entretecer
entreter
entretiver
entrevar
entrever
entrevistar
entrincheirar
entristecer
entroncar
entronizar
entrosar
entrouxar
entuchar
entulhar
entupir
enturvar
enturvecer
entusiasmar
enublar
enumerar
enunciar
envaidar
envaidecer
envasilhar
envelhacar
envelhecer
envencilhar
envenenar
enveredar
envergar
envergonhar
envernizar
envesgar
envessar
enviar
envidraçar
enviesar
envilecer
envinagrar
enviperar
enviuvar
envolver
enxadrezar
enxaguar
enxaropar
enxergar
enxertar
enxotar
enxovalhar
enxugar
enxurrar
epidemiar
epigrafar
epilogar
epistolar
epitetar
equacionar
equidistar
equilibrar
equimolecular
equipar
equiparar
equivaler
equivocar
eqüiponderar
erar
erguer
erigir
eriçar
ermar
erradicar
errar
erubescer
esbaforir
esbagaçar
esbandalhar
esbanjar
esbarrar
esbater
esbeltar
esbodegar
esbofetear
esbordoar
esboroar
esborrachar
esborratar
esborrifar
esboçar
esbracejar
esbranquiçar
esbrasear
esbravejar
esbugalhar
esbulhar
esburacar
esburnir
escacar
escachar
escafeder
escagaçar
escalar
escalavrar
escaldar
escalfar
escalonar
escalpar
escamar
escamotear
escampar
escancarar
escandalizar
escanear
escangalhar
escanhoar
escançar
escapar
escapular
escapulir
escaqueirar
escarafunchar
escaramuçar
escarcear
escarnecer
escarnir
escarpar
escarrachar
escarranchar
escarrapachar
escarrar
escassear
escavacar
escavar
escindir
esclarecer
escoar
escolar
escolher
escoltar
esconder
esconjuntar
esconjurar
escorar
escoriar
escorjar
escornar
escorraçar
escorregar
escorrer
escorropichar
escovar
escrachar
escravizar
escrever
escrevinhar
escriturar
escrutinar
escudar
escudeirar
esculachar
esculhambar
esculpir
esculturar
escurecer
escusar
escutar
esfacelar
esfaimar
esfalfar
esfaquear
esfarelar
esfarrapar
esfarripar
esfiapar
esfoguear
esfolar
esfomear
esforricar
esforçar
esfrangalhar
esfregar
esfriar
esfrolar
esfumar
esfumaçar
esfuziar
esgadanhar
esganar
esganiçar
esgaravatar
esgarrar
esgarçar
esgoelar
esgotar
esgravatar
esgrimir
esgrouviar
esguardar
esgueirar
esguelhar
esguichar
esmaecer
esmagar
esmaltar
esmar
esmatar
esmechar
esmerar
esmerilar
esmerilhar
esmigalhar
esmiolar
esmiuçar
esmocar
esmolambar
esmolar
esmorecer
esmurrar
esnobar
espacejar
espairecer
espaldar
espalhafatar
espalhar
espalmar
espanar
espancar
espanholar
espanholizar
espantar
espargir
esparramar
esparregar
esparzir
espasmar
espatifar
espatular
espaventar
espavorir
espaçar
especar
especializar
especificar
espectacular
espectar
especular
espedaçar
espelhar
esperançar
esperar
espermatizar
espernear
espertar
espessar
espetar
espevitar
espezinhar
espiar
espicaçar
espichar
espigar
espinafrar
espingardear
espinhar
espionar
espiralar
espirar
espiritualizar
espirrar
esplendecer
espoliar
espolinhar
esponjar
esporar
esporear
esposar
espraiar
espreguiçar
espreitar
espremer
espumar
espumejar
esquadrar
esquadrilhar
esquadrinhar
esquartejar
esquartelar
esquecer
esquematizar
esquentar
esquiar
esquinar
esquivar
estabelecer
estabilizar
estacar
estacionar
estafar
estagiar
estagnar
estalar
estalidar
estampar
estampilhar
estancar
estanciar
estandardizar
estanhar
estar
estardalhar
estarrecer
estatelar
estatizar
estear
estelar
estender
estenografar
estereotipar
esterilizar
estertorar
estetizar
estiar
esticar
estigmatizar
estilhar
estilhaçar
estilizar
estimar
estimular
estipular
estirar
estivar
estiver
estocar
estofar
estoirar
estontear
estontecer
estorcer
estorricar
estorvar
estourar
estradar
estragar
estrangeirar
estrangular
estranhar
estratificar
estraçalhar
estrear
estrebuchar
estreitar
estrelar
estremar
estremecer
estremunhar
estrepar
estrepitar
estressar
estribar
estrilar
estripar
estroinar
estrompar
estropiar
estrumar
estruturar
estucar
estudar
estufar
estupefazer
estupidecer
estupidificar
estuporar
estuprar
esturrar
esturricar
esvaecer
esvair
esvaziar
esventrar
esverdear
esvoaçar
eterificar
eternar
eternizar
etilizar
etiquetar
eufemizar
europeizar
evacuar
evadir
evangelizar
evaporar
evaporizar
evencer
evidenciar
evitar
evocar
evolucionar
evoluir
evolver
exacerbar
exagerar
exalar
exaltar
examinar
exarar
exarcerbar
exasperar
exatificar
exaurir
exaustar
exautorar
excecionar
exceder
excepcionar
exceptuar
excetuar
excitar
exclamar
excluir
excogitar
excomungar
excrescer
excretar
excruciar
excursionar
execrar
executar
exemplar
exemplificar
exercer
exercitar
exibir
exigir
exilar
eximir
exinanir
existir
exonerar
exorar
exorbitar
exorcizar
exortar
expandir
expatriar
expectar
expectorar
expedir
expelir
expender
experimentar
expiar
expilar
expirar
explanar
explicar
explicitar
explodir
explorar
expor
exportar
expressar
exprimir
exprobar
exprobrar
expropriar
expugnar
expulsar
expungir
expurgar
extasiar
extender
extenuar
exteriorizar
exterminar
externar
extinguir
extirpar
extorquir
extracelular
extraditar
extrair
extraparlamentar
extrapolar
extratar
extravaganciar
extravagar
extravasar
extraviar
extremar
exuberar
exular
exultar
exumar
fabricar
fabular
faccionar
facetar
facilitar
factorizar
facturar
facultar
fadar
fadigar
fagulhar
faiscar
faixar
falar
falcatruar
falcoar
falecer
falhar
falir
falsear
falsificar
faltar
familiar
familiarizar
fanar
fanatizar
fandanguear
fanfar
fanfarrear
fanfarronar
fanicar
fantasiar
fantasmagorizar
fantochar
faquear
faquir
fardar
farejar
fariscar
farolizar
farpar
farrapar
farrear
farsantear
fartar
fascinar
fasquiar
fatigar
fatorar
faturar
favorecer
faxinar
fazer
fechar
fecundar
fecundizar
feder
federalizar
federar
feirar
feitorar
feitorizar
felicitar
fender
fenecer
feriar
ferir
fermentar
ferrar
ferretar
ferretear
ferroar
ferrolhar
fertilizar
ferver
fervilhar
festejar
fiar
fibrilar
fibromuscular
ficar
fichar
figurar
filamentar
filar
filiar
filigranar
filmar
filosofar
filtrar
finalizar
financiar
finar
fincar
findar
fingir
fintar
firmar
fiscalizar
fisgar
fitar
fixar
flagar
flagelar
flagiciar
flamejar
flanar
flanquear
flautar
flautear
flavescer
flechar
flectir
flertar
flexibilizar
flexionar
florear
florescer
florir
fluir
flutuar
focalizar
focar
focinhar
foder
fofocar
foguear
foguetear
folar
folgar
folhar
folhear
folhetinizar
foliar
fomentar
foragir
forcar
forcejar
forjar
formalizar
formar
formatar
formigar
formular
fornecer
fornicar
fornir
forquilhar
forragear
forrar
fortalecer
fortificar
forçar
foscar
fosfatar
fosforar
fosforear
fosforejar
fosforescer
fosforizar
fossilizar
fotocopiar
fotografar
fotogravar
fracassar
fraccionar
fracionar
fracturar
fragmentar
franjar
franquear
franzir
fraquejar
frasear
fraternizar
fraturar
fraudar
frear
fremer
fremir
frenar
frequentar
freqüentar
fresar
fretar
fretenir
friccionar
frigir
frisar
fritar
frontear
fruir
frustrar
frutificar
fubecar
fugir
fulgir
fulgurar
fulminar
fumar
fumegar
fumigar
funcionar
fundamentar
fundar
fundear
fundir
funestar
fungar
furar
furifar
furtar
furuncular
fustigar
futilizar
futricar
futurar
fuxicar
fuzarquear
fuzilar
fuçar
gabar
gadanhar
gaguejar
gaiatar
gaifonar
galantear
galar
galardoar
galear
galgar
galhardear
galhofar
galicizar
galopar
galrar
galrear
galvanizar
gamar
gananciar
ganchar
gandaiar
ganglionar
gangrenar
ganhar
ganir
garantir
garatujar
garavetar
garfar
gargalhar
gargantear
gargarejar
garimpar
garotar
garrir
garrotar
gasear
gaseificar
gasificar
gaspear
gastar
gatafunhar
gatinhar
gatunar
gazear
gazetear
gear
gelar
gelatinizar
gelificar
gemar
gemer
gemicar
geminar
generalizar
gentilizar
gerar
gerenciar
gerir
germanizar
germinar
gessar
gesticular
gigantear
gigantizar
gingar
girar
gizar
glaciar
gladiar
glandular
glicuronizar
globular
glomerular
gloriar
glorificar
glotorar
goderar
goelar
golear
golejar
golfar
golfejar
golpear
gondolar
gorar
gorgolar
gorgolejar
gorjear
gostar
gotear
gotejar
governar
gozar
gracejar
gracitar
gradar
gradear
graduar
gralhar
gramar
gramaticar
grampear
granar
granizar
granjear
granular
grasnar
grassar
gratificar
gravar
gravetar
gravidar
gravitar
grazinar
graçolar
grelar
grelhar
gretar
grifar
grilar
grimpar
gripar
grisalhar
grisar
gritar
grossular
grudar
grugulejar
grunhir
guaiar
guardar
guardear
guarir
guarnecer
guerrear
guerrilhar
guiar
guilhotinar
guinar
guinchar
guindar
guinhar
guisar
guitarrear
gulosar
gurnir
habilitar
habitar
habituar
hachurar
halogenar
hangar
haraganear
harmonizar
harpar
harpear
harpejar
hastear
haver
hebetar
hebraizar
hectar
hegemonizar
helenizar
hepatocelular
herborizar
herdar
heroicizar
heroificar
hesitar
hibernar
hidratar
hidrogenar
hierarquizar
higienizar
hilariar
hilarizar
hiperbolizar
hipertrofiar
hipnotizar
hipotecar
hirtar
hispanizar
historiar
holandizar
homenagear
homiliar
homiziar
homogeneizar
homologar
honestar
honestizar
honorar
honorificar
honrar
horripilar
horrorisar
horrorizar
hospedar
hospitalar
hospitalizar
hostilizar
houver
humanizar
humedecer
humildar
humilhar
humorizar
iberizar
iconizar
idealizar
idear
identificar
idiotizar
idolatrar
idolatrizar
ignominiar
ignorar
igualar
igualizar
ilaquear
ilegalizar
ilhar
ilibar
ilidir
iliçar
iludir
iluminar
ilustrar
imaginar
imantar
imaterializar
imbecilizar
imbicar
imbricar
imbuir
imergir
imigrar
imiscuir
imitar
imitir
imobilizar
imolar
imortalizar
impacientar
impactar
impar
imparcializar
impassibilizar
impedir
impelir
impender
imperar
imperfeiçoar
impermeabilizar
impermear
impertinenciar
impessoalizar
impetrar
impingir
implantar
implementar
implicar
implorar
impontar
impor
importar
importunar
impossibilitar
imposturar
imprecar
impregnar
imprensar
impressionar
imprimir
improbar
impronunciar
impropriar
improvisar
impugnar
impulsar
impulsionar
impurificar
imputar
imunizar
imutar
inabilitar
inabitar
inadimplir
inalar
inanir
inativar
inaugurar
incamerar
incandescer
incapacitar
incarnar
incender
incendiar
incensar
incentivar
incestar
inchar
incidir
incinerar
incisar
incitar
inclinar
incluir
incomodar
incompatibilizar
incomunicar
incorporar
incorrer
incrementar
increpar
increr
incriminar
incrustar
incubar
inculcar
inculpar
incumbir
incutir
indagar
indeferir
indefinir
indemnizar
indenizar
indeterminar
indexar
indianizar
indicar
indiciar
indigitar
indignar
indisciplinar
individualizar
individuar
indocilizar
indrominar
indulgenciar
indultar
indumentar
industrializar
industriar
indutar
induzir
inebriar
inerciar
inervar
infamar
infantilizar
infeccionar
infectar
inferiorizar
inferir
infernar
infernizar
infestar
infiltrar
inflacionar
inflamar
inflar
inflectir
inflexionar
infligir
influenciar
influir
informar
informatizar
infortunar
infraclavicular
inframaleolar
infringir
infundibular
infundir
inglesar
ingressar
ingurgitar
inibir
inicializar
iniciar
inimistar
inimizar
injectar
injetar
injuriar
inocentar
inocular
inovar
inquietar
inquinar
inquirir
inscrever
inseminar
insensibilizar
inserir
insidiar
insinuar
insistir
insolar
insonorizar
insossar
inspeccionar
inspecionar
inspectar
inspirar
instalar
instanciar
instar
instaurar
instigar
institucionalizar
instituir
instruir
instrumentar
insubordinar
insuflar
insular
insultar
insurrecionar
integralizar
integrar
inteirar
intelectualizar
intencionar
intender
intensificar
intentar
interactuar
interagir
interauricular
intercalar
interceder
intercelular
interceptar
interclavicular
interdepender
interdisciplinar
interditar
interdizer
interessar
interestelar
interferir
interglaciar
interiorizar
interligar
interlinear
intermediar
intermeter
intermitir
intermolecular
intermuscular
internacionalizar
internalizar
internar
internuclear
interocular
interpelar
interpenetrar
interpeninsular
interpolar
interpor
interprender
interpretar
interrelacionar
interrogar
interromper
intersectar
interstelar
intervalar
interventricular
interverter
intervir
intimar
intimidar
intitular
intoxicar
intracelular
intraselar
intraventricular
intrigar
intrincar
introduzir
intrometer
introverter
intrujar
intrujir
intuir
intumescer
inundar
invadir
invalidar
invectivar
invejar
inventar
inventariar
invernar
inverter
investigar
investir
inveterar
invitar
invocar
inzonar
inçar
iodar
ionizar
ir
irar
irisar
irmanar
ironizar
irrigar
irritar
irromper
iscar
isentar
isolar
italianizar
iterar
içar
jaguar
janotar
jantar
japonesar
japonizar
jardinar
jaspear
jazer
jejuar
joelhar
jogar
jogatar
joguetar
jorrar
jovializar
jubilar
judaizar
judiar
judiciar
jugular
julgar
juncar
jungir
juntar
juramentar
jurar
justapor
justificar
justiçar
labializar
laborar
labregar
labutar
lacear
lacerar
laconizar
lacrar
lacrear
lacrimejar
lactar
lacunar
ladear
ladeirar
ladrar
ladrilhar
ladroar
lagar
lagunar
laicizar
lajear
lambar
lambariscar
lambear
lamber
lambicar
lambiscar
lambuzar
lamechar
lamelar
lamentar
laminar
lampejar
lamuriar
lanar
lancear
lancetar
lanchar
lancinar
lanhar
lantejoular
lançar
lapidar
lapisar
laquear
lar
largar
larvar
lascar
lassar
lastimar
lastrar
latejar
latinizar
latir
laurear
lavar
lavourar
lavrar
laçar
lealdar
leccionar
legalizar
legar
legislar
legitimar
leigar
leiloar
lembrar
lengalengar
lenhar
lentar
lentejoular
lenticular
ler
lesar
lesmar
letargiar
levantar
levar
levedar
levitar
lexicografar
libar
libelar
liberalizar
liberar
libertar
librar
licenciar
licitar
lidar
liderar
ligamentar
ligar
limar
limiar
liminar
limitar
limpar
linchar
linear
linearizar
linguarejar
liquefazer
liquidar
liquidificar
lisongear
lisonjear
listar
listrar
litigar
litografar
livrar
lixar
lobregar
lobular
localizar
locar
locomover
lograr
loirar
loirecer
lombar
lorotar
losangular
lotar
lotear
lourar
lourecer
lourejar
louvar
luar
lubricar
lubrificar
luchar
lucidar
lucrar
lucubrar
ludibriar
lufar
lugar
lunar
lustrar
lutar
luxar
luxuriar
luzir
macaquear
macerar
macetar
machadar
machar
machucar
macular
madeirar
madornar
madrugar
madurar
magiar
magicar
magnetizar
magnificar
magoar
majorar
malandrar
malar
malaxar
malbaratar
malbaratear
malcozer
maldar
maldizer
maldiçoar
maleabilizar
malfadar
malfazer
malgovernar
malhar
malignar
malmequer
malograr
malparar
malparir
malquerer
malquiser
malquistar
maltratar
malucar
maluquear
mamar
mamilar
manar
mancar
manchar
mandar
mandibular
mandriar
mandrionar
manducar
manejar
mangar
manhosar
manifestar
manipular
manivelar
manjar
manobrar
manquejar
manquitar
manquitolar
mantear
manter
mantiver
manufacturar
manufaturar
manumitir
manuscrever
manusear
maometanizar
mapear
maquiavelizar
maquilar
maquilhar
maquinar
mar
maragatear
marasmar
maravilhar
marcar
marceneirar
marchar
marchetar
marear
marejar
marfar
margear
marginalizar
marginar
marimbar
marinhar
mariolar
mariscar
marmorear
marmorizar
marombar
marotear
marrar
marretar
martelar
martelejar
martirizar
marujar
mascar
mascarar
mascarrar
mascatear
mascavar
masculinizar
massacrar
massagear
massajar
massificar
masterizar
mastigar
mastrear
masturbar
matar
materializar
matinar
matizar
matracar
matraquear
matricular
matrilinear
matrimoniar
maturar
matutar
maxilar
maximizar
mazelar
maçar
maçarocar
maçonizar
meandrar
mecanizar
medalhar
medianizar
mediar
mediatizar
medicamentar
medicar
medicinar
mediocrizar
medir
meditar
medrar
medular
melancolizar
melar
melhorar
melificar
melindrar
melodiar
melodizar
melodramatizar
memorar
memoriar
memorizar
mencionar
mendigar
menear
menir
menoscabar
menosprezar
menstruar
mensurar
mentalizar
mentir
mercadejar
mercantilizar
mercar
merecer
merendar
mergulhar
mesclar
mesquinhar
mestiçar
mesurar
metafisicar
metaforizar
metalizar
metamorfosear
meteorizar
meter
metodizar
metralhar
mexer
mexericar
mezinhar
miar
microfilmar
microgravar
micronodular
migrar
mijar
milenar
milhar
militar
militarizar
mimar
mimeografar
mimicar
mimosear
minar
mineralizar
minerar
mingar
minguar
miniaturar
minimizar
ministrar
minorar
minotaurizar
minuciar
minutar
miracular
mirar
mirrar
miserar
missar
missionar
mister
mistificar
misturar
mitificar
mitigar
mitrar
mixar
mnemonizar
mobilar
mobilhar
mobiliar
mobilizar
mochar
modelar
moderar
modernizar
modicar
modificar
modorrar
modular
modularizar
moer
mofar
mofumbar
moinar
moitar
molar
moldar
moldurar
molecular
molengar
molequear
molestar
molhar
molificar
molinar
molinhar
monarquizar
mondar
monetizar
monocarpelar
monocelular
monocular
monoculizar
monologar
monopolizar
montar
montear
monumentalizar
moquear
moralizar
morar
morder
mordicar
mordiscar
mordomar
morfinizar
morgar
morigerar
morrer
morrinhar
mortalhar
mortificar
moscar
mosquetear
mossar
mostrar
mostrengar
motejar
motinar
motivar
motomecanizar
motorizar
mourejar
mover
movimentar
mudar
mugir
mulher
multar
multiangular
multicelular
multicolorir
multiplicar
multipolar
mumificar
mungir
municionar
municipalizar
munir
muralhar
murar
murchar
murmurar
murmurejar
murmurinhar
muscular
musicar
mutilar
mutuar
muxoxar
nacionalizar
nadar
nadificar
namorar
namoricar
namoriscar
nanar
narcisar
narcotizar
narrar
nasalar
nasalizar
nascer
naturalizar
naufragar
nausear
navalhar
navegar
necear
necessitar
nectarizar
negacear
negar
negativar
negligenciar
negociar
negrejar
neutralizar
nevar
neviscar
nevoar
nevoentar
nicar
nicotizar
nidificar
ninar
ninhar
niquelar
nitrar
nitratar
nitrificar
nivelar
nobilitar
nobrecer
nocautear
nodular
noivar
nomadizar
nomear
nomenclar
nordestear
normalizar
noroestear
nortear
notabilizar
notar
noticiar
notificar
novar
novelar
noviciar
nuançar
nublar
nuclear
nulificar
numerar
nutrificar
nutrir
obcecar
obedecer
objectar
objectivar
objetar
objetivar
objurgar
obliquar
obliterar
obrar
obrigar
obscurantizar
obscurecer
obsedar
obsequiar
observar
obsidiar
obstar
obstinar
obstruir
obtemperar
obter
obtestar
obtiver
obtundir
obturar
obviar
ocasionar
ocidentalizar
ocorrer
octangular
ocular
ocultar
ocupar
odiar
odorar
ofegar
ofender
oferecer
oferendar
ofertar
oficializar
oficiar
ofuscar
oirar
ojerizar
oleaginar
olear
olfactar
olhar
olivar
olvidar
ombrear
ominar
omitir
ondear
ondejar
ondular
onerar
onzenar
opalescer
opalizar
operar
opercular
opiar
opinar
opor
oprimir
optar
optimizar
opugnar
opulentar
oracular
oraculizar
orar
orbicular
orbitar
ordenar
ordenhar
orfanar
organizar
orgulhar
orgulhecer
orientalizar
orientar
originar
orlar
ornamentar
ornar
ornear
ornejar
orquestrar
ortografar
orvalhar
orçamentar
orçar
oscilar
oscular
ossicular
ossificar
ostentar
otimizar
ourar
ouriçar
ousar
outonar
outorgar
ouvir
ovacionar
ovalar
ovar
ovular
oxidar
oxidular
oxigenar
ozonar
ozonificar
ozonizar
pacificar
pactear
pactuar
padecer
padejar
padrear
padronizar
paganizar
pagar
paginar
pagodear
pairar
pajear
paladar
palancar
palatalizar
palatizar
palavrear
palestrar
paletear
palhar
paliar
palidejar
palitar
palmar
palmatoar
palmatoriar
palmear
palmejar
palmilhar
palpabilizar
palpar
palpitar
palrar
panar
pandear
pandegar
panificar
pantanizar
pantear
pantentear
pantentizar
pantografar
pantominar
papaguear
papar
paparicar
papear
paquerar
parabenizar
parabolizar
paradoxar
parafinar
parafrasear
parafusar
paragrafar
paralelizar
paralisar
paralizar
paramentar
parametrizar
paramilitar
paraninfar
parapeitar
parar
parasitar
parcelar
parcializar
parear
parecer
parentear
parir
parlamentar
parlamentear
parlar
parodiar
parolar
paroquiar
parser
partafusar
partejar
participar
particular
particularizar
partilhar
partir
pascer
pascoar
pasmacear
pasmar
passar
passarinhar
passear
passivar
pastar
pastejar
pasteurizar
pastorar
pastorear
patamar
pataratar
pataratear
pategar
patentear
patetear
patinar
patinhar
patolar
patrilinear
patrocinar
patronear
patrulhar
patuscar
pausar
pautar
pavimentar
pavonear
pear
pecar
pechar
pechinchar
peculiar
pedalar
pedantear
pedicelar
pedinchar
pedir
pedrar
pegar
peguilhar
pejar
pejorar
pelar
pelear
pelejar
pelicular
pelintrar
penalizar
penar
pender
pendular
pendurar
peneirar
penejar
penetrar
penhorar
penicar
peninsular
peninuclear
peniscar
penitenciar
pensar
pensionar
pentear
penumbrar
pepinar
per
peraltar
peraltear
perambular
perceber
percepcionar
percingir
percorrer
percutir
perder
perdigotar
perdoar
perdulariar
perdurar
perecer
peregrinar
perenizar
pererecar
perfazer
perfectibilizar
perfilar
perfilhar
perfumar
perfurar
perguntar
periclitar
perigar
perimir
periocular
periodizar
perjurar
perlongar
permanecer
permeabilizar
permear
permitir
permutar
pernoitar
pernoutar
perpassar
perpendicular
perpetrar
perpetuar
perquirir
perscrutar
perseguir
perseverar
persistir
persolver
personalizar
personificar
perspectivar
perspirar
persuadir
pertencer
perturbar
peruar
pervagar
pervencer
perverter
pervoeirar
pesar
pescar
pescocear
pespegar
pespontar
pespontear
pesquisar
pessoalizar
pestanear
pestanejar
peticionar
petiscar
petrificar
peçonhentar
piabar
pianizar
piar
picar
pichar
picotar
pifar
pigarrear
pigmentar
pilar
pilhar
pilheriar
pilotar
pimpar
pimponar
pincelar
pinchar
pindarizar
pingar
pinicar
pinotear
pintalgar
pintar
pinçar
piorar
piparotar
pipocar
pirangar
pirar
piratear
piriricar
pirotecnizar
pirracear
pirraçar
piruetar
pisar
piscar
pisgar
pisotear
pitar
plagiar
planar
planear
planejar
planger
planificar
plantar
plasmar
plasticizar
plastificar
platinar
plebeizar
plebiscitar
pleitear
plicar
plissar
plugar
pluralizar
pluricelular
podar
poder
poetar
poetizar
poisar
pojar
polar
polarizar
polcar
polegar
polemizar
policelular
policiar
polinizar
polinuclear
polir
politicar
politizar
poluir
polvilhar
pomar
pombear
pomificar
pompear
ponderar
pongar
pontapear
pontear
pontificar
pontilhar
pontuar
popular
popularizar
por
porfiar
pormenorizar
pornografar
pororocar
portar
portear
portugalizar
porvir
posar
posicionar
positivar
pospor
possear
possibilitar
possibitar
possuir
postar
postergar
posterizar
postular
potenciar
poupar
pousar
povoar
pracear
pradejar
praguejar
pranchar
prantear
pratear
praticar
prazentear
prazer
prealegar
preambular
preanunciar
precatar
precautelar
precaver
preceder
preceituar
precipitar
precisar
preconceber
preconizar
predefinir
predestinar
predeterminar
predicar
predispor
predizer
predominar
preencher
preestabelecer
preexistir
prefaciar
preferir
prefigurar
prefinir
prefixar
pregar
pregoar
preguear
preguiçar
prejudicar
prejulgar
prelevar
prelibar
preliminar
preludiar
prelustrar
premeditar
premer
premiar
premir
premunir
prendar
prender
prenominar
prensar
prenunciar
preocupar
preopercular
preordenar
preparar
preponderar
prepor
presar
prescindir
prescrever
presenciar
presentar
presentear
preservar
presidiar
presidir
pressagiar
pressentir
pressionar
pressupor
pressurizar
prestar
prestigiar
presumir
pretejar
pretender
preterir
pretextar
prevalecer
prevaricar
prevenir
prever
previr
prezar
primar
primaverar
principiar
privar
privatizar
privilegiar
probabilizar
problematizar
proceder
processar
proclamar
procrastinar
procriar
procurar
prodigalizar
produzir
profanar
proferir
professar
professorar
profetizar
profissionalizar
profligar
profundar
prognosticar
programar
programatizar
progredir
proibir
projectar
projetar
prolatar
proletarizar
proliferar
prologar
prolongar
promanar
prometer
promiscuir
promover
promulgar
pronomiar
prontificar
pronunciar
propagandear
propagar
propalar
propelir
propender
propiciar
propor
proporcionar
propugnar
propulsar
propulsionar
prorrogar
prorromper
prosar
proscrever
prosear
prospectar
prosperar
prosseguir
prosternar
prostituir
prostrar
protagonizar
proteger
protelar
protestar
protocolar
protocolizar
prototificar
protrair
prouver
provar
prover
proverbiar
providenciar
provincianizar
provir
provisionar
provocar
prumar
prurir
pubescer
publicar
publicitar
puder
puerilizar
pugilar
pugnar
puir
pujar
pular
pulmonar
pulpar
pulsar
pulsear
pulverizar
pungir
punguear
punir
pupilar
purgar
purificar
purpurar
putrefazer
putrificar
puxar
pôr
quadrangular
quadrar
quadricular
quadrilocular
quadrinizar
quadruplar
quadruplicar
quaisquer
qualificar
qualquer
quantificar
quarar
quarentar
quarentenar
quaresmar
quartear
quebrantar
quebrar
quedar
queijar
queimar
queixar
quentar
querelar
querer
questionar
quicar
quietar
quilatar
quilhar
quilometrar
quimerizar
quimificar
quinar
quintar
quintuplicar
quiser
quitar
quotizar
rabear
rabequear
rabiscar
rabujar
rabular
rachar
raciocinar
racionalizar
racionar
radar
radiar
radicalizar
radicar
radicular
radiodifundir
radioemitir
radiografar
rafar
raiar
raivecer
rajar
ralar
ralear
ralhar
ramalhar
ramificar
ranger
ranzinzar
rançar
rapar
rapinar
raposar
raptar
rarear
rarefazer
rasar
rascar
rascunhar
rasgar
raspançar
raspar
rastear
rastejar
rastilhar
rastrear
rastrejar
rasurar
ratar
ratazanar
ratear
ratificar
ratonar
ravinar
razar
raziar
razoar
reabastecer
reabilitar
reabitar
reabituar
reabrir
readaptar
readmitir
readquirir
reafirmar
reagir
reagravar
reagrupar
reajustar
realizar
realçar
reanimar
reaparecer
reaquecer
rearmar
reassenhorear
reassumir
reatar
reativar
reatribuir
reavaliar
reaver
reaviar
reavivar
rebaixar
rebarbar
rebater
rebelar
rebelionar
rebentar
rebitar
rebocar
rebolar
rebolear
rebolir
rebombar
rebulir
rebuliçar
rebuscar
recalcar
recalcificar
recalcitrar
recalcular
recambiar
recapar
recapitular
recargar
recarregar
recatar
recauchutar
recear
receber
receitar
recensear
recessitar
rechaçar
rechear
reciclar
reciprocar
recitar
reclamar
reclassificar
reclinar
recobrar
recolher
recolocar
recomendar
recomeçar
recompensar
reconcentrar
reconciliar
recondicionar
reconduzir
reconfigurar
reconfirmar
reconfortar
reconhecer
reconquistar
reconsiderar
reconsolidar
recontar
reconvocar
recopiar
recopilar
recordar
recorrer
recortar
recostar
recrear
recrescer
recriar
recriminar
recrudescer
recrutar
rectangular
rectificar
recuar
recumbir
recuperar
recursar
recusar
redar
redefinir
redesenhar
redibir
redigir
redigitar
redimensionar
redimir
redirecionar
redobrar
redondear
redopiar
redundar
reduzir
reedificar
reeditar
reeducar
reembarcar
reembolsar
reemitir
reempossar
reempregar
reencadernar
reencapar
reencarnar
reencontrar
reentrar
reenumerar
reequipar
reestipular
reestruturar
reestudar
reexaminar
reexibir
refastelar
refazer
refecer
refegar
referenciar
referendar
referir
refestelar
refilar
refinanciar
refinar
reflectir
refletir
reflexionar
refluir
refogar
refolgar
refolhar
reformar
reformular
refortalecer
refortificar
reforçar
refractar
refrear
refregar
refrescar
refrigerar
refugar
refugiar
refulgir
refundir
refutar
regalar
reganhar
regar
regatar
regatear
regaçar
regelar
regenerar
reger
regimentar
registar
registrar
regozijar
regrar
regredir
regressar
regulamentar
regular
regularizar
regurgitar
reimplantar
reimprimir
reinar
reincidir
reincorporar
reinfundir
reingressar
reinicializar
reiniciar
reinstalar
reintegrar
reintroduzir
reiterar
reivindicar
rejeitar
rejubilar
rejuvenescer
relacionar
relampaguear
relampear
relampejar
relancear
relançar
relatar
relaxar
relegar
relembrar
relentar
reler
relevar
relinchar
relumbrar
relutar
reluzir
relvar
relvejar
remanchar
remanescer
remar
remarcar
rematar
remedar
remediar
remedir
rememorar
remendar
remeter
remexer
remir
remitir
remobilhar
remobilizar
remocar
remodelar
remoinhar
remontar
remorder
remover
remoçar
remunerar
renascer
rendar
render
rendilhar
renegar
renhir
renitir
renomear
renovar
renunciar
reocupar
reorganizar
repaginar
reparar
repartir
repassar
repatriar
repelir
repenicar
repensar
repercutir
repetir
repicar
repimpar
repisar
replantar
repletar
replicar
repontar
reportar
repousar
repreender
represar
representar
reprimir
reprochar
reproduzir
reprovar
reptar
republicanizar
republicar
repudiar
repugnar
repulsar
reputar
repuxar
requebrar
requeimar
requentar
requerer
requestar
requestrar
requintar
requisitar
rescaldar
rescindir
rescrever
resenhar
reservar
resfolegar
resfolgar
resfriar
resgatar
resguardar
residir
resignar
resinar
resistir
reslumbrar
resmungar
resolver
respeitar
respigar
respingar
respirar
resplandecer
resplendecer
resplender
responder
responsabilizar
responsar
ressabiar
ressacar
ressaltar
ressalvar
ressarcir
ressecar
ressentir
ressequir
ressoar
ressonar
ressuscitar
restabelecer
restar
restaurar
restilar
restinguir
restituir
restringir
restucar
resultar
resumir
resvalar
retalhar
retaliar
retardar
retemperar
retesar
reticenciar
reticular
retificar
retinir
retirar
retocar
retomar
retornar
retorquir
retractar
retrair
retransmitir
retratar
retraçar
retribuir
retroagir
retroceder
retrogradar
retroverter
retrucar
retumbar
retundir
reunificar
reunir
reurbanizar
revalidar
revalorizar
revelar
revender
rever
reverberar
reverdecer
reverenciar
reversar
reverter
revestir
revezar
revidar
revigorar
revir
revirar
revisar
revisitar
revistar
revitalizar
reviver
revivescer
revocar
revogar
revoltar
revoltear
revolucionar
revolver
rezar
rezingar
ribombar
ricochetar
ricochetear
ridicularizar
rifar
rilhar
rimar
rinchar
ringir
rinhar
ripar
ripostar
rir
riscar
ritmar
rivalizar
rixar
roborar
robotizar
robustecer
rocegar
rociar
rodar
rodear
rodopiar
roer
rogar
rojar
rolar
rolhar
romancear
romanizar
romantizar
romper
roncar
roncear
rondar
ronquejar
ronronar
rorejar
rosar
roscar
rosear
rosnar
rosquear
rostear
rotar
rotular
roubar
roufenhar
rouquejar
roxear
roçar
rubescer
ruborescer
ruborizar
rubricar
rudimentar
rufar
rufiar
rugir
ruir
rumar
ruminar
rumorejar
ruralizar
rusgar
russificar
rustificar
rustilar
rustir
ruçar
saber
sabichar
saborear
sabotar
sabujar
sacanear
sacar
sachar
sacholar
saciar
sacolejar
sacralizar
sacramentar
sacrificar
sacudir
safar
sagrar
sair
salariar
saldar
salgar
salientar
salificar
salivar
salmodiar
salpicar
saltar
saltaricar
saltarilhar
saltear
saltitar
salubrificar
salutar
salvaguardar
salvar
sambar
sanar
sanatorizar
sancionar
sandejar
sanduichar
sanear
sangrar
sanguificar
santificar
sapatear
sapear
sapecar
saquear
saracotear
saraivar
sarapintar
sarar
sarilhar
sarjar
sarnir
sarrabiscar
sarrar
satanizar
satirizar
satisfazer
saturar
saudar
sazonar
saçaricar
scanner
secar
seccionar
secionar
secretar
secretariar
secular
secularizar
secundar
sedar
sedimentar
seduzir
segmentar
segredar
segregar
seguir
segundar
segurar
selar
seleccionar
selecionar
semear
semelhar
sementar
semicerrar
semicircular
semiviver
sengar
senhorear
sensaborizar
sensibilizar
sensualizar
sentar
sentenciar
sentimentalizar
sentir
separar
sepultar
sequestrar
sequiar
seqüestrar
ser
serenar
seriar
seringar
sermonar
serpear
serpentar
serpentear
serrar
serrotear
sertanejar
sertanizar
servilizar
servir
setear
setorizar
sevandijar
severizar
seviciar
sextuplicar
sexualizar
sibilantizar
sibilar
siderar
sigilar
significar
silabar
silenciar
silhuetar
silvar
simbolizar
simetrizar
similar
simpatizar
simplificar
simular
sinalizar
sincronizar
sindicalizar
sindicar
sinfonizar
singrar
singular
singularizar
sinistrar
sinonimar
sinonimizar
sintetizar
sintonizar
sirigaitar
sisar
sistematizar
sitiar
situar
soalhar
soar
sobejar
soberanizar
sobrancear
sobrar
sobraçar
sobrealimentar
sobreavisar
sobrecarregar
sobreexcitar
sobreirritar
sobrelevar
sobreluzir
sobrenaturalizar
sobrenomear
sobreolhar
sobrepensar
sobrepesar
sobrepor
sobrepovoar
sobrepujar
sobresair
sobrescrever
sobressair
sobressaltar
sobressaturar
sobrestimar
sobrevir
sobreviver
sobrevoar
socalcar
socar
sociabilizar
socializar
socorrer
soer
soerguer
sofismar
sofisticar
sofrear
sofregar
sofrer
solapar
solar
solavancar
soldar
solenizar
soletrar
solevantar
solevar
solfejar
solicitar
solidar
solidarizar
solidificar
solinhar
soltar
solubilizar
solucionar
soluçar
solver
somar
sombrear
sombrejar
sonambular
sondar
sonegar
sonetar
sonhar
sonorizar
sopapear
sopear
sopesar
sopitar
soprar
sopresar
soquear
sornar
sorrir
sortear
sortir
sorvar
sorver
sossegar
soterrar
souber
sovar
soverter
sovietizar
sovinar
soçobrar
suar
suavisar
suavizar
subalimentar
subalternar
subalternizar
subalugar
subalveolar
subandar
subarrendar
subassinar
subclassificar
subclavicular
subdelegar
subdirigir
subdistinguir
subdividir
subentender
subestimar
subintender
subintitular
subir
subjectivar
subjetivar
subjugar
subjulgar
sublevar
sublimar
subliminar
sublinear
sublinhar
sublocar
submergir
submeter
subministrar
subordinar
subornar
subpolar
subpor
subscrever
subsecretariar
subsidiar
subsistir
substancializar
substanciar
substantivar
substituir
subsumir
subterrar
subtilizar
subtrair
subutilizar
subvencionar
subverter
suceder
suciar
sucumbir
suestar
sufixar
sufocar
sufragar
sugar
sugerir
sugestionar
sugilar
suicidar
sujar
sujeitar
sulcar
sulfatar
sulfatizar
sulfurar
sumariar
sumir
sumular
sungar
supeditar
superabundar
superalimentar
superar
superativar
superescalar
superestimar
superexcitar
superintender
superiorizar
superlativar
superlotar
supervisar
supervisionar
suplantar
suplementar
suplicar
supliciar
supor
suportar
supraescapular
supralunar
suprimir
suprir
supurar
surdir
surgir
surpreender
surpresar
surrar
surripiar
surrupiar
surtir
susceptibilizar
suscetibilizar
suscitar
suspeitar
suspender
suspirar
sussurrar
sustar
sustenizar
sustentar
suster
sutilizar
suturar
suxar
tabaquear
tabelar
tabular
tacanhear
tachar
tachear
tactear
tagarelar
talar
talhar
taludar
tamborilar
tampar
tangar
tangenciar
tanger
tantalizar
tapar
tapear
tapetar
taquigrafar
tarar
tardar
tarear
tarefar
tarifar
tarjar
tarraxar
tartamudear
tascar
tatear
tatuar
taxar
taxiar
tear
teatralizar
tecar
tecer
tecidular
teclar
teimar
telar
telecomandar
teledirigir
telefonar
telegrafar
teleguiar
televisar
televisionar
telhar
telintar
temer
temperar
tempestear
tempestuar
temporalizar
temporizar
tencionar
tender
tentacular
tentar
tentear
teocratizar
teologizar
teorizar
ter
terminar
termonuclear
termopar
terraplanar
terrificar
terçar
tesar
tesoirar
tesourar
testar
testemunhar
testicular
testificar
testilhar
tetanizar
ticar
tilintar
timbrar
timonar
tingir
tinir
tintinar
tipificar
tiquetaquear
tiranizar
tirar
tiritar
tirotear
tisicar
tisnar
titubear
titular
tlintar
toar
tocar
togar
toirear
toldar
tolerar
tolher
tomar
tombar
tombolar
tonalizar
tonar
tonificar
tontear
topar
topografar
torar
torcer
tornar
tornear
torpecer
torpedar
torpedear
torpor
torrar
torrear
torrificar
torturar
torvar
tosar
toscar
tosquiar
tossicar
tossir
tostar
totalizar
toucar
tourear
trabalhar
tracejar
traduzir
trafegar
traficar
tragar
trair
trajar
tralhar
tramar
trambecar
trambicar
trambolhar
tramitar
trampear
tranar
trancafiar
trancar
tranquilizar
tranqüilizar
transaccionar
transacionar
transar
transbordar
transcendentalizar
transcender
transcorrer
transcrever
transferir
transfigurar
transformar
transgredir
transigir
transitar
transitivar
transladar
translucidar
transmitir
transmudar
transmutar
transnadar
transnavegar
transparecer
transparentar
transpassar
transpirar
transplantar
transpor
transportar
transtornar
transubstanciar
transvasar
transvazar
transverberar
transverter
transviar
transvoar
trançar
trapacear
trapear
trapejar
traquejar
traquinar
trasladar
trasmontar
trasncorrer
traspassar
trastejar
tratantear
tratar
traumatizar
trautear
travar
travejar
travessar
travessear
travestir
trazer
traçar
treinar
trejeitar
trejeitear
tremar
tremelicar
tremeluzir
tremer
tremular
trepar
trepidar
treplicar
tresandar
trescalar
tresloucar
tresmalhar
tresnoitar
trespassar
trespor
triangular
tributar
tricotar
tricotear
trilar
trilhar
trinar
trincafiar
trincar
trinchar
tripartir
triplicar
tripudiar
tripular
triturar
triunfar
trivializar
troar
trocadilhar
trocar
trombar
trombetear
trombicar
tropeçar
tropicar
trotar
trotear
trovar
trovejar
troviscar
trovoar
troçar
trucar
trucidar
trufar
truncar
trunfar
tubular
tufar
tugir
tumeficar
tumular
tumultuar
tungar
turbar
turbilhonar
turrar
turturinar
turvar
turvejar
tutear
tutelar
tutorar
ufanar
uivar
ulcerar
ultimar
ultrajar
ultramar
ultrapassar
ulular
umedecer
unanimar
ungir
unhar
unicarpelar
unicelular
unificar
uniformizar
unilocular
unipolar
unir
universalizar
untar
urbanizar
urdir
urgir
urinar
urrar
urticar
urtigar
urubuzar
usar
usufruir
usufrutuar
usurar
usurpar
utilizar
vacilar
vacinar
vadear
vadiar
vagabundar
vagabundear
vagamundear
vagar
vaguear
vaguejar
vaiar
valar
valer
validar
valorar
valorizar
valsar
valvar
valvular
vampirizar
vandalizar
vangloriar
vanguardear
vaporar
vaporizar
vapular
vaqueanar
vaqueirar
vaquejar
varar
varejar
variar
varrer
vasconcear
vascular
vasculhar
vasquear
vasquejar
vassalar
vassoirar
vassourar
vaticinar
vazar
vaziar
vedar
veementizar
vegetar
veicular
velar
velejar
velhacar
velhaquear
venalizar
vencer
vendar
vender
venerar
venializar
ventanear
ventanejar
ventar
ventilar
ventricular
ver
veranear
verbalizar
verberar
verdascar
verdear
verdecer
verdejar
verear
vergalhar
vergar
vergastar
verificar
vermelhar
vermelhecer
vermicular
vernaculizar
verrumar
versar
versejar
versificar
verter
verticalizar
vesguear
vesicular
vestibular
vestir
vetar
vexar
viajar
vibrar
vicejar
viciar
vidrar
vigarizar
viger
vigiar
vigilar
vigorar
vigorizar
vilificar
vilipendiar
vinagrar
vincar
vincular
vindicar
vindimar
vingar
vinificar
violar
violentar
vir
virar
viravoltar
viravoltear
virginalizar
virgular
virilizar
visar
viscondizar
visionar
visitar
vislumbrar
vistorar
vistoriar
visualizar
vitalizar
vitaminar
vitaminizar
vitimar
vitoriar
vitrificar
vituperar
viuvar
vivenciar
viver
vivificar
vizinhar
vizir
voar
vocabular
vocabulizar
vocalizar
vociferar
voejar
vogar
volatear
volatilizar
volatizar
voltar
voltear
voltejar
volumar
volver
vomitar
votar
vozear
vulcanizar
vulgar
vulgarizar
vulnerar
vunzar
xaropar
xeretar
xerografar
xingar
zabumbar
zaguchar
zangar
zangarrear
zanzar
zaragatear
zaranzar
zarelhar
zarpar
zebrar
zelar
zerar
ziguezaguear
zimbrar
zincar
zingarear
zingrar
ziziar
zoar
zombar
zombetear
zonzar
zonzear
zumbar
zumbir
zumbrir
zunir
zunzunar
zunzunir
zurrar
zurupar
zurzir
EOSTR
    ;
1 ;
