#!/usr/bin/perl

# Created by ./mk_str_mod.pl on Wed Jan 28 22:21:25 PST 2009

package Lingua::PT::VerbSuffixes ;
use Exporter ;
@ISA = qw(Exporter);
@EXPORT = qw( $verb_suffixes );
$verb_suffixes = <<EOSTR
a cpres,1,er,ir,r,uer,uir
a cpres,3,er,ir,r,uer,uir
a imp,1,r
a imp,3,r
a ivo,3,er,ir,r,uer,uir
a mdp,1,
a mdp,3,
ais cpres,5,edir,enir,entir,er,estir,ir,r,uer,uir
am cpres,6,er,ir,r,uer,uir
am imp,6,r
am ivo,6,er,ir,r,uer,uir
am mdp,6,
am perf,6,
amos cpres,4,er,ir,r,uer,uir
amos ivo,4,er,ir,r,uer,uir
as cpres,2,er,ir,r,uer,uir
as imp,2,r
as mdp,2,
ca cpres,1,der
ca cpres,3,der
ca ivo,3,der
cais cpres,4,der
cam cpres,6,der
cam ivo,6,der
camos ivo,4,der
cas cpres,2,der
ce cpres,1,çar
ce cpres,3,çar
ce ivo,3,çar
cei perf,1,çar
ceis cpres,5,çar
cem cpres,6,çar
cem ivo,6,çar
cemos cpres,4,çar
cemos ivo,4,çar
ces cpres,2,çar
co pres,1,der
cto pp,1,içoar
de ivo,5,r
de ivo,6,r
deie cpres,1,ndiar
des cfut,5,
des pres,5,r
do pp,1,r,scer
e cpres,1,ar
e cpres,3,ar
e ivo,2,ir
e ivo,3,ar
e pp,1,ar
e pres,3,ir
ecto pp,1,igir
edvais cpres,5,advir
ei fut,1,
ei perf,1,ar
ei pres,1,aber,aver
eia ivo,2,iar
eia pres,3,iar
eiam pres,6,iar
eias pres,2,iar
eie cpres,1,iar
eie cpres,3,iar
eie ivo,3,iar
eieis cpres,5,iar
eiem cpres,6,iar
eiem ivo,6,iar
eies cpres,2,iar
eio perf,3,ir
eio pres,1,iar
eirdes cfut,5,ar
eis cpres,5,ar
eis fut,5,
eito pp,1,azer
eja cpres,1,ar
eja cpres,3,ar
ejais cpres,5,ar
ejam cpres,6,ar
ejam ivo,6,ar
ejamos cpres,4,ar
ejamos ivo,4,ar
ejas cpres,2,ar
em cfut,6,
em cpres,6,ar
em ivo,6,ar
em pres,3,ir
em pres,6,ir,r
emos cpres,4,ar
emos fut,4,
emos ivo,4,ar
emos perf,4,ar,r
enha cpres,1,ir
enha cpres,3,ir
enha ivo,3,ir
enhais cpres,5,ir
enham cpres,6,ir
enham ivo,6,ir
enhamos cpres,4,ir
enhamos ivo,4,ir
enhas cpres,2,ir
enhas ivo,2,ir
enho pres,1,ir
ens pres,2,ir
envais cpres,5,onvir
er cfut,1,ar,r
er cfut,3,ar,r
era imp,1,ser
era imp,3,ser
era mdp,1,ar,r
era mdp,3,ar,r
eram imp,6,ser
eram mdp,6,ar,r
eram perf,6,ar,r
eras imp,2,ser
eras mdp,2,ar,r
erem cfut,6,ar,r
eres cfut,2,ar,r
ermos cfut,4,ar,r
erto pp,1,rir
es cfut,2,
es cpres,2,ar
es pres,2,ir
esse cimp,1,ar,r
esse cimp,3,ar,r
essem cimp,6,ar,r
esses cimp,2,ar,r
esso pp,1,imir,itir
este perf,2,ar,r
estes perf,5,ar
eu perf,3,ar
evais cpres,5,over
eve perf,3,ar
ez perf,3,azer
foi perf,3,ir,ser
fomos perf,4,ir,ser
for cfut,1,ir,ser
for cfut,3,ir,ser
fora mdp,1,ser
fora mdp,3,ser
foram cfut,6,ir
foram mdp,6,ser
foram perf,6,ir,ser
foras mdp,2,ser
fordes cfut,5,ir,ser
forem cfut,6,ser
fores cfut,2,ir,ser
formos cfut,4,ir,ser
fosse cimp,1,ir,ser
fosse cimp,3,ir,ser
fossem cimp,6,ir,ser
fosses cimp,2,ir,ser
foste perf,2,ir,ser
fostes perf,5,ir,ser
fui perf,1,ir,ser
fôramos mdp,4,ser
fôreis mdp,5,ser
fôsseis cimp,5,ir,ser
fôssemos cimp,4,ir,ser
ga cpres,1,zer
ga cpres,3,zer
ga ivo,3,zer
gais cpres,5,zer
gam cpres,6,zer
gam ivo,6,zer
gamos cpres,4,zer
gamos ivo,4,zer
gas cpres,2,zer
gei ivo,5,zer
go pres,1,zer
grato pp,1,agradecer
ha cpres,1,er
ha cpres,3,er
ha ivo,3,er
hais cpres,5,er
ham cpres,6,er
ham ivo,6,er
hamos cpres,4,er
hamos ivo,4,er
has cpres,2,er
ho pres,1,er
i ivo,2,ar
i ivo,5,r
i perf,1,er
i pres,3,ar
ia cond,1,
ia cond,3,
ia cpres,1,r
ia cpres,3,r
ia imp,1,er
ia imp,3,er
ia ivo,2,ar
ia ivo,3,r
ia pres,3,ar
iais cpres,5,r
iam cond,6,
iam cpres,6,r
iam imp,6,er
iam ivo,6,r
iam pres,6,ar
iamos cpres,4,r
iamos ivo,4,r
ias cond,2,
ias cpres,2,r
ias imp,2,er
ias pres,2,ar
iba cpres,1,ber
iba cpres,3,ber
iba ivo,3,ber
ibais cpres,5,ber
ibam cpres,6,ber
ibam ivo,6,ber
ibamos cpres,4,ber
ibamos ivo,4,ber
ibas cpres,2,ber
ibo pres,1,ber
icta cpres,1,ectir
icta cpres,3,ectir
icta ivo,3,ectir
ictais cpres,5,ectir
ictam cpres,6,ectir
ictam ivo,6,ectir
ictamos cpres,4,ectir
ictamos ivo,4,ectir
ictas cpres,2,ectir
icto pp,1,encer
icto pres,1,ectir
ida cpres,1,edir
ida cpres,3,edir
ida ivo,3,edir
idais cpres,5,edir
idam cpres,6,edir
idam ivo,6,edir
idamos cpres,4,edir
idamos ivo,4,edir
idas cpres,2,edir
ide ivo,2,edir
ide pres,3,edir
idem pres,6,edir
ides pres,2,edir
idis pres,5,edir
ido pp,1,er
ido pres,1,edir
ie cpres,1,ar
ie cpres,3,ar
ie ivo,3,ar,ear
iem cpres,6,ar
iem ivo,6,ar,ear
ies cpres,2,ar
iga cpres,1,eguir
iga cpres,3,eguir
iga ivo,3,eguir
igais cpres,5,eguir
igam cpres,6,eguir
igam ivo,6,eguir
igamos cpres,4,eguir
igamos ivo,4,eguir
igas cpres,2,eguir
igo pres,1,eguir
ila cpres,1,elir
ila cpres,3,elir
ila ivo,3,elir
ilais cpres,5,elir,ler
ilam cpres,6,elir
ilam ivo,6,elir
ilamos cpres,4,elir
ilamos ivo,4,elir
ilas cpres,2,elir
ilo pres,1,elir
imos perf,4,er
ina cpres,1,enir
ina cpres,3,enir
ina ivo,3,enir
inam cpres,6,enir
inam ivo,6,enir
inamos cpres,4,enir
inamos ivo,4,enir
inas cpres,2,enir
ine ivo,2,enir
ine pres,3,enir
inem pres,6,enir
ines pres,2,enir
inha imp,1,er
inha imp,3,er
inham imp,6,er
inhas imp,2,er
inis pres,5,enir
ino pres,1,enir
inta cpres,1,entir
inta cpres,3,entir
inta ivo,3,entir
intais cpres,5,entir
intam cpres,6,entir
intam ivo,6,entir
intamos cpres,4,entir
intamos ivo,4,entir
intas cpres,2,entir
into pres,1,entir
io pres,1,ar,r
ir cfut,1,er
ir cfut,3,er
ira cpres,1,erir,rer
ira cpres,3,erir,rer
ira ivo,3,erir,rer
ira mdp,1,er
ira mdp,3,er
irais cpres,5,erir,rer
iram cpres,6,erir,rer
iram ivo,6,erir,rer
iram mdp,6,er
iram perf,6,er
iramos cpres,4,erir,rer
iramos ivo,4,erir,rer
iras cpres,2,erir,rer
iras mdp,2,er
irdes cfut,5,er
irem cfut,6,er
ires cfut,2,er
irmos cfut,4,er
iro pres,1,erir,rer
irta cpres,1,ertir
irta cpres,3,ertir
irta ivo,3,ertir
irtais cpres,5,ertir
irtam cpres,6,ertir
irtam ivo,6,ertir
irtamos cpres,4,ertir
irtamos ivo,4,ertir
irtas cpres,2,ertir
irto pres,1,ertir
irva cpres,1,ervir
irva cpres,3,ervir
irva ivo,3,ervir
irvais cpres,5,ervir
irvam cpres,6,ervir
irvam ivo,6,ervir
irvamos cpres,4,ervir
irvamos ivo,4,ervir
irvas cpres,2,ervir
irvo pres,1,ervir
is perf,1,erer
is perf,3,erer
is pres,2,ar
is pres,5,r
isemos perf,4,erer
iser cfut,1,erer
iser cfut,3,erer
isera mdp,1,erer
isera mdp,3,erer
iseram mdp,6,erer
iseram perf,6,erer
iseras mdp,2,erer
iserdes cfut,5,erer
iserem cfut,6,erer
iseres cfut,2,erer
isermos cfut,4,erer
isesse cimp,1,erer
isesse cimp,3,erer
isessem cimp,6,erer
isesses cimp,2,erer
iseste perf,2,erer
isse cimp,1,er
isse cimp,3,er
issem cimp,6,er
isses cimp,2,er
isso pp,1,eter
ista cpres,1,estir
ista cpres,3,estir
ista ivo,3,estir
istam cpres,6,estir
istam ivo,6,estir
istamos cpres,4,estir
istamos ivo,4,estir
istas cpres,2,estir
iste perf,2,er
isto pp,1,er
isto pres,1,estir
iséramos mdp,4,erer
iséssemos cimp,4,erer
isêreis mdp,5,erer
isêsseis cimp,5,erer
ita cpres,1,etir
ita cpres,3,etir
ita ivo,3,etir
itais cpres,5,etir
itam cpres,6,etir
itam ivo,6,etir
itamos cpres,4,etir
itamos ivo,4,etir
itas cpres,2,etir
ito pp,1,ever,ger
ito pres,1,etir
iu perf,3,er
ive perf,1,ar,er
ivemos perf,4,ar,er
iver cfut,1,ar,er
iver cfut,3,ar,er
ivera mdp,1,ar,er
ivera mdp,3,ar,er
iveram mdp,6,er
iveram perf,6,ar,er
iveras mdp,2,ar,er
iverdes cfut,5,ar,er
iverem cfut,6,ar,er
iveres cfut,2,ar,er
ivermos cfut,4,ar,er
iverãm mdp,6,ar
ivesse cimp,1,ar,er
ivesse cimp,3,ar,er
ivessem cimp,6,ar,er
ivesses cimp,2,ar,er
iveste perf,2,ar,er
ivestes perf,5,ar,er
ivéramos mdp,4,ar,er
ivéreis mdp,5,ar,er
ivésseis cimp,5,ar,er
ivéssemos cimp,4,ar,er
iz perf,1,azer
izemos perf,4,azer
izer cfut,1,azer
izer cfut,3,azer
izera mdp,1,azer
izera mdp,3,azer
izeram mdp,6,azer
izeram perf,6,azer
izeras mdp,2,azer
izerdes cfut,5,azer
izerem cfut,6,azer
izeres cfut,2,azer
izermos cfut,4,azer
izesse cimp,1,azer
izesse cimp,3,azer
izessem cimp,6,azer
izesses cimp,2,azer
izeste perf,2,azer
izêramos mdp,4,azer
izêreis mdp,5,azer
izêsseis cimp,5,azer
izêssemos cimp,4,azer
iça cpres,1,uvir
iça cpres,3,uvir
iça ivo,3,uvir
içais cpres,5,uvir
içam cpres,6,uvir
içam ivo,6,uvir
içamos cpres,4,uvir
içamos ivo,4,uvir
iças cpres,2,uvir
iço pres,1,uvir
ja cpres,1,ger,gir,r,ver
ja cpres,3,ger,gir,r,ver
ja ivo,3,ger,gir,r,ver
jais cpres,5,ger,gir,r,ver
jam cpres,6,ger,gir,r,ver
jam ivo,6,ger,gir,r,ver
jamos cpres,4,ger,gir,r,ver
jamos ivo,4,ger,gir,r,ver
jas cpres,2,ger,gir,r,ver
jas ivo,2,ver
jo pres,1,ger,gir,r
jueado pp,1,guear
jueai ivo,5,guear
jueais pres,5,guear
jueamos perf,4,guear
jueamos pres,4,guear
jueando grd,1,guear
juear cfut,1,guear
juear cfut,3,guear
jueara mdp,1,guear
jueara mdp,3,guear
juearam mdp,6,guear
juearam perf,6,guear
juearas mdp,2,guear
jueardes cfut,5,guear
juearei fut,1,guear
jueareis fut,5,guear
juearem cfut,6,guear
juearemos fut,4,guear
jueares cfut,2,guear
juearia cond,1,guear
juearia cond,3,guear
jueariam cond,6,guear
juearias cond,2,guear
juearmos cfut,4,guear
jueará fut,3,guear
juearás fut,2,guear
juearão fut,6,guear
juearíamos cond,4,guear
juearíeis cond,5,guear
jueasse cimp,1,guear
jueasse cimp,3,guear
jueassem cimp,6,guear
jueasses cimp,2,guear
jueaste perf,2,guear
jueastes perf,5,guear
jueava imp,1,guear
jueava imp,3,guear
jueavam imp,6,guear
jueavas imp,2,guear
jueei perf,1,guear
jueeis cpres,5,guear
jueemos cpres,4,guear
jueemos ivo,4,guear
jueia ivo,2,guear
jueia pres,3,guear
jueiam pres,6,guear
jueias pres,2,guear
jueie cpres,1,guear
jueie cpres,3,guear
jueiem cpres,6,guear
jueies cpres,2,guear
jueio pres,1,guear
jueou perf,3,guear
jueáramos mdp,4,guear
jueáreis mdp,5,guear
jueásseis cimp,5,guear
jueássemos cimp,4,guear
jueávamos imp,4,guear
jueáveis imp,5,guear
juie ivo,3,guear
juiem ivo,6,guear
luto pp,1,ver
m ivo,2,r
m perf,1,r
m perf,6,r
m pres,3,r
m pres,6,r
mirdes cfut,5,r
mos cfut,4,
mos perf,4,r
mos pres,4,r
mísseis cimp,5,r
nde ivo,5,r
ndes pres,5,r
ndo grd,1,r
ndo pp,1,r
nha cpres,1,r
nha cpres,3,r
nha imp,1,r
nha imp,3,r
nha ivo,3,r
nhais cpres,5,r
nham cpres,6,r
nham imp,6,r
nham ivo,6,r
nhamos cpres,4,r
nhamos ivo,4,r
nhas cpres,2,r
nhas imp,2,r
nho pres,1,r
ns pres,2,r
o pp,1,ar,ivar
o pres,1,ar,er,ir,r,uer,uir
obe ivo,2,ubir
obe pres,3,ubir
obem pres,6,ubir
obes pres,2,ubir
oem pres,6,uir
oge ivo,2,ugir
oge pres,3,ugir
ogem pres,6,ugir
oges pres,2,ugir
oiemos cpres,4,iar
oiemos ivo,4,iar
ois pres,5,er
omos pres,4,er,ôr
onde ivo,5,ôr
ondes pres,5,ôr
ondo grd,1,ôr
onha cpres,1,ôr
onha cpres,3,ôr
onha ivo,3,ôr
onhais cpres,5,ôr
onham cpres,6,ôr
onham ivo,6,ôr
onhamos cpres,4,ôr
onhamos ivo,4,ôr
onhas cpres,2,ôr
onho pres,1,ôr
orei fut,1,ôr
oreis fut,5,ôr
oremos fut,4,ôr
oria cond,1,ôr
oria cond,3,ôr
oriam cond,6,ôr
orias cond,2,ôr
orto pp,1,atar
orá fut,3,ôr
orás fut,2,ôr
orão fut,6,ôr
oríamos cond,4,ôr
oríeis cond,5,ôr
osto pp,1,ôr
ou perf,3,ar
ou pres,1,ar,er
oube perf,1,aber
oube perf,3,aber
oubemos perf,4,aber
ouber cfut,1,aber
ouber cfut,3,aber
oubera mdp,1,aber
oubera mdp,3,aber
ouberam mdp,6,aber
ouberam perf,6,aber
ouberas mdp,2,aber
ouberdes cfut,5,aber
ouberem cfut,6,aber
ouberes cfut,2,aber
oubermos cfut,4,aber
oubesse cimp,1,aber
oubesse cimp,3,aber
oubessem cimp,6,aber
oubesses cimp,2,aber
oubeste perf,2,aber
oubestes perf,5,aber
oubeu perf,3,aber
oubéramos mdp,4,aber
oubéssemos cimp,4,aber
oubêreis mdp,5,aber
oubêsseis cimp,5,aber
ouve perf,1,aver
ouve perf,3,aver
ouvemos perf,4,aver
ouver cfut,1,aver
ouver cfut,3,aver
ouvera mdp,1,aver
ouvera mdp,3,aver
ouveram mdp,6,aver
ouveram perf,6,aver
ouveras mdp,2,aver
ouverdes cfut,5,aver
ouverem cfut,6,aver
ouveres cfut,2,aver
ouvermos cfut,4,aver
ouvesse cimp,1,aver
ouvesse cimp,3,aver
ouvessem cimp,6,aver
ouvesses cimp,2,aver
ouveste perf,2,aver
ouvestes perf,5,aver
ouvéramos mdp,4,aver
ouvéreis mdp,5,aver
ouvésseis cimp,5,aver
ouvéssemos cimp,4,aver
ouxe perf,1,azer
ouxemos perf,4,azer
ouxer cfut,1,azer
ouxer cfut,3,azer
ouxera mdp,1,azer
ouxera mdp,3,azer
ouxeram mdp,6,azer
ouxeram perf,6,azer
ouxeras mdp,2,azer
ouxerdes cfut,5,azer
ouxerem cfut,6,azer
ouxeres cfut,2,azer
ouxermos cfut,4,azer
ouxesse cimp,1,azer
ouxesse cimp,3,azer
ouxessem cimp,6,azer
ouxesses cimp,2,azer
ouxeste perf,2,azer
ouxestes perf,5,azer
ouxeu perf,3,azer
ouxéramos mdp,4,azer
ouxêreis mdp,5,azer
ouxêsseis cimp,5,azer
ouxêssemos cimp,4,azer
que cpres,1,car
que cpres,3,car
que ivo,3,car
queado pp,1,cear
queai ivo,5,cear
queais pres,5,cear
queamos perf,4,cear
queamos pres,4,cear
queando grd,1,cear
quear cfut,1,cear
quear cfut,3,cear
queara mdp,1,cear
queara mdp,3,cear
quearam mdp,6,cear
quearam perf,6,cear
quearas mdp,2,cear
queardes cfut,5,cear
quearei fut,1,cear
queareis fut,5,cear
quearem cfut,6,cear
quearemos fut,4,cear
queares cfut,2,cear
quearia cond,1,cear
quearia cond,3,cear
queariam cond,6,cear
quearias cond,2,cear
quearmos cfut,4,cear
queará fut,3,cear
quearás fut,2,cear
quearão fut,6,cear
quearíamos cond,4,cear
quearíeis cond,5,cear
queasse cimp,1,cear
queasse cimp,3,cear
queassem cimp,6,cear
queasses cimp,2,cear
queaste perf,2,cear
queastes perf,5,cear
queava imp,1,cear
queava imp,3,cear
queavam imp,6,cear
queavas imp,2,cear
queei perf,1,cear
queeis cpres,5,cear
queemos cpres,4,cear
queemos ivo,4,cear
quei perf,1,car
queia ivo,2,cear
queia pres,3,cear
queiam pres,6,cear
queias pres,2,cear
queie cpres,1,cear
queie cpres,3,cear
queiem cpres,6,cear
queies cpres,2,cear
queio pres,1,cear
queis cpres,5,car
quem cpres,6,car
quem ivo,6,car
quemos cpres,4,car
quemos ivo,4,car
queou perf,3,cear
ques cpres,2,car
queáramos mdp,4,cear
queáreis mdp,5,cear
queásseis cimp,5,cear
queássemos cimp,4,cear
queávamos imp,4,cear
queáveis imp,5,cear
quie ivo,3,cear
quiem ivo,6,cear
rei fut,1,zer
reis fut,5,zer
remos fut,4,zer
ria cond,1,zer
ria cond,3,zer
riam cond,6,zer
rias cond,2,zer
rá fut,3,zer
rás fut,2,zer
rão fut,6,zer
ríamos cond,4,zer
ríeis cond,5,zer
s perf,3,r
s pres,2,r
s pres,5,r
so pp,1,der,gir,ir,nder,ter
ssa cpres,1,der
ssa cpres,3,der
ssa ivo,3,der
ssais cpres,5,der
ssam cpres,6,der
ssam ivo,6,der
ssamos cpres,4,der
ssamos ivo,4,der
ssas cpres,2,der
sse cimp,1,r
sse cimp,3,r
sse perf,1,zer
sse perf,3,zer
ssem cimp,6,r
ssemos perf,4,zer
sser cfut,1,zer
sser cfut,3,zer
sseram perf,6,zer
sserdes cfut,5,zer
sserem cfut,6,zer
sseres cfut,2,zer
ssermos cfut,4,zer
sses cimp,2,r
ssesse cimp,1,zer
ssesse cimp,3,zer
ssessem cimp,6,zer
ssesses cimp,2,zer
sseste perf,2,zer
sso pres,1,der
ssêsseis cimp,5,zer
ssêssemos cimp,4,zer
ste perf,2,r
stes perf,5,r
sto pp,1,r
to pp,1,der,gar,gir,guir,ir,mper,rer,ver,zer
u perf,3,r
ubra cpres,1,obrir
ubra cpres,3,obrir
ubrais cpres,5,obrir
ubram cpres,6,obrir
ubramos cpres,4,obrir
ubras cpres,2,obrir
ubro pres,1,obrir
ude perf,1,oder
udemos perf,4,oder
uder cfut,1,oder
uder cfut,3,oder
udera mdp,1,oder
udera mdp,3,oder
uderam mdp,6,oder
uderam perf,6,oder
uderas mdp,2,oder
uderdes cfut,5,oder
uderem cfut,6,oder
uderes cfut,2,oder
udermos cfut,4,oder
udesse cimp,1,oder
udesse cimp,3,oder
udessem cimp,6,oder
udesses cimp,2,oder
udeste perf,2,oder
udéssemos cimp,4,oder
udêramos mdp,4,oder
udêreis mdp,5,oder
udêsseis cimp,5,oder
ue cpres,1,ar
ue cpres,3,ar
ue ivo,3,ar
ue pp,1,ar
uei perf,1,ar
ueis cpres,5,ar
uem cpres,6,ar
uem ivo,6,ar
uemos cpres,4,ar
uemos ivo,4,ar
ues cpres,2,ar
ula cpres,1,olir
ula cpres,3,olir
ula ivo,3,olir
ulais cpres,5,olir
ulam cpres,6,olir
ulam ivo,6,olir
ulamos cpres,4,olir
ulamos ivo,4,olir
ulas cpres,2,olir
ule ivo,2,olir
ule pres,3,olir
ulem pres,6,olir
ules pres,2,olir
ulo pres,1,olir
ulso pp,1,elir
unha imp,1,or,ôr
unha imp,3,or,ôr
unham imp,6,or,ôr
unhas imp,2,or,ôr
upto pp,1,omper
urma cpres,1,ormir
urma cpres,3,ormir
urmais cpres,5,ormir
urmam cpres,6,ormir
urmamos cpres,4,ormir
urmas cpres,2,ormir
urmo pres,1,ormir
urso pp,1,orrer
us perf,1,or,ôr
usemos perf,4,or,ôr
user cfut,1,or,ôr
user cfut,3,or,ôr
usera mdp,1,or,ôr
usera mdp,3,or,ôr
useram mdp,6,or,ôr
useram perf,6,or,ôr
useras mdp,2,or,ôr
userdes cfut,5,or,ôr
userem cfut,6,or,ôr
useres cfut,2,or,ôr
usermos cfut,4,or,ôr
usesse cimp,1,or,ôr
usesse cimp,3,or,ôr
usessem cimp,6,or,ôr
usesses cimp,2,or,ôr
useste perf,2,or,ôr
usestes perf,5,or,ôr
uséramos mdp,4,or,ôr
uséreis mdp,5,or,ôr
usésseis cimp,5,ôr
uséssemos cimp,4,or,ôr
uésseis cimp,5,or
va imp,1,r
va imp,3,r
vades cpres,5,ir
vai ivo,2,ir
vai pres,3,ir
vais pres,2,ir
vam imp,6,r
vamos cpres,4,ir
vamos ivo,4,ir
vamos pres,4,ir
vas imp,2,r
ve perf,3,r
vou pres,1,ir
vá cpres,1,ir
vá cpres,3,ir
vá ivo,3,ir
vás cpres,2,ir
vão cpres,6,ir
vão ivo,6,ir
vão pres,6,ir
á fut,3,
á ivo,2,ar
á pres,3,ar,aver
áramos mdp,4,ar
áreis mdp,5,ar
ás fut,2,
ás pres,2,ar,aver
ásseis cimp,5,ar
ássemos cimp,4,ar
ávamos imp,4,ar
áveis imp,5,ar
ão fut,6,
ão pres,6,ar,aver,er
ça cpres,1,cer,cir,dir,vir,zer
ça cpres,3,cer,cir,dir,vir,zer
ça ivo,3,cer,cir,dir,zer
çais cpres,5,cer,cir,dir,vir,zer
çam cpres,6,cer,cir,dir,vir,zer
çam ivo,6,cer,cir,dir,vir,zer
çamos cpres,4,cer,cir,dir,vir,zer
çamos ivo,4,cer,cir,dir,vir,zer
ças cpres,2,cer,cir,dir,vir,zer
çauteado pp,1,cautear
çauteai ivo,5,cautear
çauteais pres,5,cautear
çauteamos perf,4,cautear
çauteamos pres,4,cautear
çauteando grd,1,cautear
çautear cfut,1,cautear
çautear cfut,3,cautear
çauteara mdp,1,cautear
çauteara mdp,3,cautear
çautearam mdp,6,cautear
çautearam perf,6,cautear
çautearas mdp,2,cautear
çauteardes cfut,5,cautear
çautearei fut,1,cautear
çauteareis fut,5,cautear
çautearem cfut,6,cautear
çautearemos fut,4,cautear
çauteares cfut,2,cautear
çautearia cond,1,cautear
çautearia cond,3,cautear
çauteariam cond,6,cautear
çautearias cond,2,cautear
çautearmos cfut,4,cautear
çauteará fut,3,cautear
çautearás fut,2,cautear
çautearão fut,6,cautear
çautearíamos cond,4,cautear
çautearíeis cond,5,cautear
çauteasse cimp,1,cautear
çauteasse cimp,3,cautear
çauteassem cimp,6,cautear
çauteasses cimp,2,cautear
çauteaste perf,2,cautear
çauteastes perf,5,cautear
çauteava imp,1,cautear
çauteava imp,3,cautear
çauteavam imp,6,cautear
çauteavas imp,2,cautear
çauteei perf,1,cautear
çauteeis cpres,5,cautear
çauteemos cpres,4,cautear
çauteemos ivo,4,cautear
çauteia ivo,2,cautear
çauteia pres,3,cautear
çauteiam pres,6,cautear
çauteias pres,2,cautear
çauteie cpres,1,cautear
çauteie cpres,3,cautear
çauteiem cpres,6,cautear
çauteies cpres,2,cautear
çauteio pres,1,cautear
çauteou perf,3,cautear
çauteáramos mdp,4,cautear
çauteáreis mdp,5,cautear
çauteásseis cimp,5,cautear
çauteássemos cimp,4,cautear
çauteávamos imp,4,cautear
çauteáveis imp,5,cautear
çautie ivo,3,cautear
çautiem ivo,6,cautear
ço pres,1,cer,cir,dir,vir,zer
çoa ivo,2,coar
çoa pres,3,coar
çoado pp,1,coar
çoai ivo,5,coar
çoais pres,5,coar
çoam pres,6,coar
çoamos perf,4,coar
çoamos pres,4,coar
çoando grd,1,coar
çoar cfut,1,coar
çoar cfut,3,coar
çoara mdp,1,coar
çoara mdp,3,coar
çoaram mdp,6,coar
çoaram perf,6,coar
çoaras mdp,2,coar
çoardes cfut,5,coar
çoarei fut,1,coar
çoareis fut,5,coar
çoarem cfut,6,coar
çoaremos fut,4,coar
çoares cfut,2,coar
çoaria cond,1,coar
çoaria cond,3,coar
çoariam cond,6,coar
çoarias cond,2,coar
çoarmos cfut,4,coar
çoará fut,3,coar
çoarás fut,2,coar
çoarão fut,6,coar
çoaríamos cond,4,coar
çoaríeis cond,5,coar
çoas pres,2,coar
çoasse cimp,1,coar
çoasse cimp,3,coar
çoassem cimp,6,coar
çoasses cimp,2,coar
çoaste perf,2,coar
çoastes perf,5,coar
çoava imp,1,coar
çoava imp,3,coar
çoavam imp,6,coar
çoavas imp,2,coar
çoe cpres,1,coar
çoe cpres,3,coar
çoe ivo,3,coar
çoei perf,1,coar
çoeis cpres,5,coar
çoem cpres,6,coar
çoem ivo,6,coar
çoemos cpres,4,coar
çoemos ivo,4,coar
çoes cpres,2,coar
çoo pres,1,coar
çoou perf,3,coar
çoáramos mdp,4,coar
çoáreis mdp,5,coar
çoásseis cimp,5,coar
çoássemos cimp,4,coar
çoávamos imp,4,coar
çoáveis imp,5,coar
é pres,3,ser
éja ivo,3,ar
ém ivo,2,er
ém pres,3,er
éns pres,2,er
éramos imp,4,ser
éramos mdp,4,ar,r
éreis imp,5,ser
és pres,2,ser
éssemos cimp,4,r
ê cpres,1,ar
ê cpres,3,ar
ê ivo,2,er
ê ivo,3,ar
ê pres,3,er
êem cpres,6,ar
êem ivo,6,ar
êem pres,6,er
êia ivo,3,er
êm pres,6,er,ir
êmos cpres,4,ar
êramos mdp,4,er
êreis mdp,5,er
ês cpres,2,ar
ês pres,2,er
êsseis cimp,5,ar,er
êssemos cimp,4,ar,er
í ivo,5,ir
í perf,1,er,ir
ía imp,1,er,ir
ía imp,3,er,ir
íam imp,6,er,ir
íamos cond,3,
íamos cond,4,
íamos cpres,4,ir
íamos imp,4,er,ir
ías imp,2,er,ir
ído pp,1,er,ir
íeis cond,4,
íeis cond,5,
íeis cpres,5,ir
íeis imp,5,er,ir
ímos perf,4,ir
ímos pres,4,ir
ínhamos imp,4,er,ir
ínheis imp,5,er
íra mdp,1,ir
íra mdp,3,ir
íram mdp,6,ir
íram perf,6,ir
íramos mdp,4,er,ir
íras mdp,2,ir
írdes cfut,5,ir
íreis mdp,5,er,ir
írem cfut,6,ir
íres cfut,2,ir
ís pres,2,er
ís pres,5,ir
ísse cimp,1,ir
ísse cimp,3,ir
ísseis cimp,5,ir
íssem cimp,6,ir
íssemos cimp,4,ir
ísses cimp,2,ir
íste perf,2,ir
ístes perf,5,ir
îsseis cimp,5,er
îssemos cimp,4,er
ói ivo,2,oer
ói pres,3,oer,uir
óia ivo,2,iar,oiar
óia pres,3,iar,oiar
óiais pres,5,iar,oiar
óiam pres,6,iar,oiar
óiamos pres,4,iar,oiar
óias pres,2,iar,oiar
óie cpres,1,iar,oiar
óie cpres,3,iar,oiar
óie ivo,3,iar,oiar
óieis cpres,5,iar
óiem cpres,6,iar,oiar
óiem ivo,6,iar,oiar
óies cpres,2,iar,oiar
óio pres,1,iar,oiar
óis pres,2,uir
ôde perf,3,oder
ôs perf,3,or
õe ivo,2,or,ôr
õe pres,3,or,ôr
õem pres,6,or,ôr
ões pres,2,or,ôr
úe cpres,1,uar
úe cpres,3,uar
úe ivo,3,uar
úeis cpres,5,uar
úem cpres,6,uar
úem ivo,6,uar
úemos cpres,4,uar
úes cpres,2,uar
únhamos imp,4,or,ôr
únheis imp,5,or,ôr

EOSTR
    ;
1 ;
